#!/bin/bash

# TEST VERSION
DEBUG_MODE=1

######################################################
#Default output directory
OUTPUT_DIR="."

#Output sub-directory name
OUTPUT_SUBDIR_L1=data-collection-$(date "+%Y%m%d%H%M%S")
OUTPUT_SUBDIR_L2_1="physical-configuration"
OUTPUT_SUBDIR_L2_2="virtual-configuration"
DATA_COLLECTION_START_FILE_NAME="data-collection-start"
DATA_COLLECTION_END_FILE_NAME="data-collection-end"
COLLECT_SCRIPT_DIR_NAME="Collection_scripts"
OUTPUT_SUBDIR_LOGS=${OUTPUT_SUBDIR_L1}_LOGS
######################################################

######################################################
#VM, CLIENT, LDOM, COMSTAR HOSTNAMES (edit this part if necessary)
CLIENT_HOSTNAME=(bur407-106 bur407-108 bur407-110 bur407-112 bur407-87 bur407-182 bur407-186 bur407-191 bur407-90 bur407-124 bur397-119)
LDOM_HOSTNAME=(bur407-67 bur407-70)
COMSTAR_HOSTNAME=(bur407-117 bur407-104 bur407-63 bur407-120)
VM_TYPE=(web infra db japp mail batch)
MAX_TILE_NUM=34
for vm in ${VM_TYPE[@]}
do
	VM=$(echo $vm | tr [a-z] [A-Z])
	for ((i=0; i<${MAX_TILE_NUM}; i++))
	do
		((l_index=i+1))
		eval ${VM}_HOSTNAME[$i]="${vm}${l_index}"
	done
done 
TILE_RANGE="{1..${#WEB_HOSTNAME[@]}}"
VM_RANGE="web infra db japp mail batch"
CLIENT_NUM=${#CLIENT_HOSTNAME[@]}
LDOM_NUM=${#LDOM_HOSTNAME[@]}
COMSTAR_NUM=${#COMSTAR_HOSTNAME[@]}
IS_LDOM=0
###
# TILE MAPPING based on TILE+TYPE
# VM_TYPE specified the order in the table.  The entries are the LDOM index for that tile.
# Row 0 Is NULL and not to be used. Valid entries are 1...33
#
# A  dictionary with bash key:value the Key is tile index; The value is an LDOM number
# for this configuration there are two LDOMS: 0 and 1
# order of value entries matches VM_TYPE enumeration. 0 index is not to be used.
TILE_MAP=( "0:0,0,0,0,0,0"
"1:0,0,0,0,0,0" "2:0,0,0,0,0,0" "3:0,0,0,0,0,0" "4:0,0,0,0,0,0"
"5:1,1,1,1,1,1" "6:1,1,1,1,1,1" "7:1,1,1,1,1,1" "8:1,1,1,1,1,1"
"9:0,0,0,0,0,0" "10:0,0,0,0,0,0" "11:0,0,0,0,0,0" "12:0,0,0,0,0,0"
"13:1,1,1,1,1,1" "14:1,1,1,1,1,1" "15:1,1,1,1,1,1" "16:1,1,1,1,1,1"
"17:0,0,0,0,0,0" "18:0,0,0,0,0,0" "19:0,0,0,0,0,0" "20:0,0,0,0,0,0"
"21:1,1,1,1,1,1" "22:1,1,1,1,1,1" "23:1,1,1,1,1,1" "24:1,1,1,1,1,1"
"25:0,0,0,0,0,0" "26:0,0,0,0,0,0" "27:0,0,0,0,0,0" "28:0,0,0,0,0,0"
"29:1,1,1,1,1,1" "30:1,1,1,1,1,1" "31:1,1,1,1,1,1" "32:1,1,1,1,1,1"
"33:0,0,1,1,1,0" "34:0,0,1,1,1,0"
 )
WEB=0
INFRA=1
DB=2
JAPP=3
MAIL=4
BATCH=5

# Global variable as return value from tile_map function
ldomN=0
# Func: given an index and tile type, return via global the LDOM number
function tile_map() {  # tile-index Tile-type

  i=$1
  TYPE=$2
  # Entries are delimited by comma. Read entries into array tile_entry
  IFS=', ' read -a tile_entry  <<< " ${TILE_MAP[$i]#*:}"

  echo ${tile_entry[$TYPE]}
  ldomN=${tile_entry[$TYPE]}

}


######################################################


function usage()
{ 
        echo "Usage:"
	echo "TESTspecvirt_config_collect.sh [-h] [-o directory] [-ldom/LDOM] [-comstar|COMSTAR] [-tile] [[-web] [-infra] [-db] [-japp] [-mail] [-batch] [-client] [-sut]] | [-all]" 
        echo "-h: show usage"
        echo "-o	<output_dir>"
	echo "-ldom/LDOM"
	echo "-comstar/COMSTAR"
	echo "-tile	<tile_range> [even|odd]"
        echo "-web	"
        echo "-infra	"
        echo "-db	"
        echo "-japp	"
        echo "-mail	"
        echo "-batch	"
        echo "-client	"
        echo "-sut	"
        echo "-all	"
	echo ""
}

function collect_web()
{
	if (($DEBUG_MODE == 1));
	then
		echo "collect web config"
	fi

#  return 0

	for i in $(eval echo $TILE_RANGE);
	do
		eval l_web_hostname=${WEB_HOSTNAME[$((i-1))]}
		l_web_dir=${OUTPUT_DIR}/${OUTPUT_SUBDIR_L1}/${OUTPUT_SUBDIR_L2_2}/tile${i}/webserver
		l_web_dir_vm=${l_web_dir}/VM_Configuration
		l_web_dir_sw=${l_web_dir}/Software_Configuration
                l_web_dir_logs=${OUTPUT_SUBDIR_LOGS}/weblogs
		mkdir -p ${l_web_dir_sw}/opt/oracle/webserver7/https-wstest-T4SSL/config
		mkdir -p ${l_web_dir_vm}/etc
		mkdir -p ${l_web_dir_vm}/tmp
		mkdir -p ${l_web_dir_logs}
#		mkdir -p ${l_web_dir_vm}/http_logs
		cp /etc/zones/${l_web_hostname}.xml ${l_web_dir}
		if (($IS_LDOM == 1));
		then
                        tile_map $i $WEB
                        l_ldom_hostname=${LDOM_HOSTNAME[$ldomN]}
			#l_ldom_hostname=${LDOM_HOSTNAME[${TILE_TO_LDOM[$i]}]}
			echo "Connecting LDOM $l_ldom_hostname TILE$i ${l_web_hostname}"
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"ifconfig -a\"" > ${l_web_dir_vm}/ifconfig.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"pkg list -v\"" > ${l_web_dir_vm}/pkglist.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"cat /root/.rhosts\"" > ${l_web_dir_vm}/.rhosts 
                        rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"cat /opt/oracle/webserver7/https-wstest-T4SSL/start_it_support\"" >${l_web_dir_sw}/opt/oracle/webserver7/https-wstest-T4SSL/start_it_support
                        rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"cat /opt/oracle/webserver7/https-wstest-T4SSL/config/magnus.conf\"" >${l_web_dir_sw}/opt/oracle/webserver7/https-wstest-T4SSL/config/magnus.conf
                        rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"cat /opt/oracle/webserver7/https-wstest-T4SSL/config/obj.conf\"" >${l_web_dir_sw}/opt/oracle/webserver7/https-wstest-T4SSL/config/obj.conf
                        rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"cat /opt/oracle/webserver7/https-wstest-T4SSL/config/server.xml\"" >${l_web_dir_sw}/opt/oracle/webserver7/https-wstest-T4SSL/config/server.xml
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"echo '<?php phpinfo();  ?>' |php\"" > ${l_web_dir_sw}/phpinfo.out 
			rsh ${l_ldom_hostname} "rm -r /tmp/https-wstest-T4SSL"
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"cat /etc/hosts\"" > ${l_web_dir_vm}/etc/hosts
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"cat /tmp/pollme.g${l_web_hostname}\"" > ${l_web_dir_vm}/tmp/pollme.g${l_web_hostname}
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"cat /http_logs/errors\"" > ${l_web_dir_logs}/web_tile${i}_errors
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"cat /http_logs/access\"" > ${l_web_dir_logs}/web_tile${i}_access
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"cat /http_logs/Fastcgistub.log\"" > ${l_web_dir_logs}/web_tile${i}_Fastcgistub.log
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"df -h\"" > ${l_web_dir_vm}/df.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"hostname\"" > ${l_web_dir_vm}/hostname.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"mount -v\"" > ${l_web_dir_vm}/mount.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"ps -eaf\"" > ${l_web_dir_vm}/ps-eaf.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"ps -eaflc\"" > ${l_web_dir_vm}/ps-eaflc.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"netstat -a\"" > ${l_web_dir_vm}/netstat.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"uname\"" > ${l_web_dir_vm}/uname.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"uptime\"" > ${l_web_dir_vm}/uptime.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"dladm show-vnic\"" > ${l_web_dir_vm}/dladm_show-vnic.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"svcs\"" > ${l_web_dir_vm}/svcs.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"zpool status\"" > ${l_web_dir_vm}/zpool-status.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"cat /etc/release\"" > ${l_web_dir_vm}/etc/release
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"cat /etc/nsswitch.conf\"" > ${l_web_dir_vm}/etc/nsswitch.conf
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"cat /etc/inittab\"" > ${l_web_dir_vm}/etc/inittab
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"cat /etc/vfstab\"" > ${l_web_dir_vm}/etc/vfstab
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"swap -l\"" > ${l_web_dir_vm}/swap.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"psrinfo -pv\"" > ${l_web_dir_vm}/psrinfo.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"prtconf\"" > ${l_web_dir_vm}/prtconf.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"zpool list rpool\"" > ${l_web_dir_vm}/zpool_list.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"psrset -Q 1\"" > ${l_web_dir_vm}/psrset-Q_1.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"psrset -Q 2\"" > ${l_web_dir_vm}/psrset-Q_2.txt
			rsh ${l_ldom_hostname} "zlogin ${l_web_hostname} \"zfs get all http_logs\"" > ${l_web_dir_vm}/zfs_get_http_logs.txt
		else
			echo "Connecting TILE$i via ${l_web_hostname}"
			zlogin ${l_web_hostname} "ifconfig -a" > ${l_web_dir_vm}/ifconfig.txt
			zlogin ${l_web_hostname} "pkg list -v" > ${l_web_dir_vm}/pkglist.txt
			rcp g${l_web_hostname}:/root/.rhosts ${l_web_dir_vm}
                        rcp g${l_web_hostname}:/opt/oracle/webserver7/https-wstest-T4SSL/start_it_support ${l_web_dir_sw}/opt/oracle/webserver7/https-wstest-T4SSL/start_it_support
                        rcp g${l_web_hostname}:/opt/oracle/webserver7/https-wstest-T4SSL/config/magnus.conf ${l_web_dir_sw}/opt/oracle/webserver7/https-wstest-T4SSL/config/magnus.conf
                        rcp g${l_web_hostname}:/opt/oracle/webserver7/https-wstest-T4SSL/config/obj.conf ${l_web_dir_sw}/opt/oracle/webserver7/https-wstest-T4SSL/config/obj.conf
                        rcp g${l_web_hostname}:/opt/oracle/webserver7/https-wstest-T4SSL/config/server.xml ${l_web_dir_sw}/opt/oracle/webserver7/https-wstest-T4SSL/config/server.xml
			zlogin ${l_web_hostname} "echo '<?php phpinfo();  ?>' |php" > ${l_web_dir_sw}/phpinfo.out 
			rcp g${l_web_hostname}:/etc/hosts ${l_web_dir_vm}/etc
			rcp g${l_web_hostname}:/tmp/pollme.g${l_web_hostname} ${l_web_dir_vm}/tmp
			rcp g${l_web_hostname}:/http_logs/errors ${l_web_dir_logs}/web_tile${i}_errors
			rcp g${l_web_hostname}:/http_logs/access ${l_web_dir_logs}/web_tile${i}_access
			rcp g${l_web_hostname}:/http_logs/Fastcgistub.log ${l_web_dir_logs}/web_tile${i}_Fastcgistub.log
			zlogin ${l_web_hostname} "df -h" > ${l_web_dir_vm}/df.txt
			zlogin ${l_web_hostname} "hostname" > ${l_web_dir_vm}/hostname.txt
			zlogin ${l_web_hostname} "mount -v" > ${l_web_dir_vm}/mount.txt
			zlogin ${l_web_hostname} "ps -eaf" > ${l_web_dir_vm}/ps-eaf.txt
			zlogin ${l_web_hostname} "netstat -a" > ${l_web_dir_vm}/netstat.txt
			zlogin ${l_web_hostname} "uname" > ${l_web_dir_vm}/uname.txt
			zlogin ${l_web_hostname} "uptime" > ${l_web_dir_vm}/uptime.txt
			zlogin ${l_web_hostname} "dladm show-vnic" > ${l_web_dir_vm}/dladm_show-vnic.txt
			zlogin ${l_web_hostname} "svcs" > ${l_web_dir_vm}/svcs.txt
			zlogin ${l_web_hostname} "zpool status" > ${l_web_dir_vm}/zpool-status.txt
			zlogin ${l_web_hostname} "cat /etc/release" > ${l_web_dir_vm}/etc/release
			zlogin ${l_web_hostname} "cat /etc/nsswitch.conf" > ${l_web_dir_vm}/etc/nsswitch.conf
			zlogin ${l_web_hostname} "cat /etc/inittab" > ${l_web_dir_vm}/etc/inittab
			zlogin ${l_web_hostname} "cat /etc/vfstab" > ${l_web_dir_vm}/etc/vfstab
			zlogin ${l_web_hostname} "swap -l" > ${l_web_dir_vm}/swap.txt
			zlogin ${l_web_hostname} "psrinfo -pv" > ${l_web_dir_vm}/psrinfo.txt
			zlogin ${l_web_hostname} "prtconf" > ${l_web_dir_vm}/prtconf.txt
			zlogin ${l_web_hostname} "zpool list rpool" > ${l_web_dir_vm}/zpool_list.txt
			zlogin ${l_web_hostname} "zfs get all http_logs" > ${l_web_dir_vm}/zfs_get_http_logs.txt
		fi
	done
	echo ""
}

function collect_infra()
{
        if (($DEBUG_MODE == 1));
        then
                echo "collect infra config"
        fi
 
 #return 0

	for i in $(eval echo $TILE_RANGE);
	do
		eval l_infra_hostname=${INFRA_HOSTNAME[$((i-1))]}
                l_infra_dir=${OUTPUT_DIR}/${OUTPUT_SUBDIR_L1}/${OUTPUT_SUBDIR_L2_2}/tile${i}/infraserver
		l_infra_dir_vm=${l_infra_dir}/VM_Configuration
		l_infra_dir_sw=${l_infra_dir}/Software_Configuration
                l_infra_dir_logs=${OUTPUT_SUBDIR_LOGS}/infralogs
		mkdir -p ${l_infra_dir_sw}/opt/oracle/webserver7/https-besim/config
		mkdir -p ${l_infra_dir_vm}/etc
		mkdir -p ${l_infra_dir_vm}/tmp
		mkdir -p ${l_infra_dir_logs}
#		mkdir -p ${l_infra_dir_vm}/http_logs
		cp /etc/zones/${l_infra_hostname}.xml ${l_infra_dir}
		if (($IS_LDOM == 1));
		then
                        tile_map $i $INFRA
                        l_ldom_hostname=${LDOM_HOSTNAME[$ldomN]}
			#l_ldom_hostname=${LDOM_HOSTNAME[${TILE_TO_LDOM[$i]}]}
			echo "Connecting LDOM $l_ldom_hostname TILE$i ${l_infra_hostname}"
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"ifconfig -a\"" > ${l_infra_dir_vm}/ifconfig.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"pkg list -v\"" > ${l_infra_dir_vm}/pkglist.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"cat /root/.rhosts\"" > ${l_infra_dir_vm}/.rhosts 
                        rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"cat /opt/oracle/webserver7/https-besim/start_it\"" > ${l_infra_dir_sw}/opt/oracle/webserver7/https-besim/start_it
                        rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"cat /opt/oracle/webserver7/https-besim/config/magnus.conf\"" > ${l_infra_dir_sw}/opt/oracle/webserver7/https-besim/config/magnus.conf
                        rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"cat /opt/oracle/webserver7/https-besim/config/obj.conf\"" > ${l_infra_dir_sw}/opt/oracle/webserver7/https-besim/config/obj.conf
                        rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"cat /opt/oracle/webserver7/https-besim/config/server.xml\"" > ${l_infra_dir_sw}/opt/oracle/webserver7/https-besim/config/server.xml
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"cat /etc/hosts\"" > ${l_infra_dir_vm}/etc/hosts
                        rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"cat /tmp/pollme.g${l_infra_hostname}\"" > ${l_infra_dir_vm}/tmp/pollme.g${l_infra_hostname}
                        rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"cat /http_logs/errors\"" > ${l_infra_dir_logs}/infra_tile${i}_errors
                        rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"cat /http_logs/access\"" > ${l_infra_dir_logs}/infra_tile${i}_access
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"df -h\"" > ${l_infra_dir_vm}/df.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"hostname\"" > ${l_infra_dir_vm}/hostname.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"mount -v\"" > ${l_infra_dir_vm}/mount.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"ps -eaf\"" > ${l_infra_dir_vm}/ps-eaf.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"ps -eaflc\"" > ${l_infra_dir_vm}/ps-eaflc.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"netstat -a\"" > ${l_infra_dir_vm}/netstat.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"uname\"" > ${l_infra_dir_vm}/uname.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"uptime\"" > ${l_infra_dir_vm}/uptime.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"dladm show-vnic\"" > ${l_infra_dir_vm}/dladm_show-vnic.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"svcs\"" > ${l_infra_dir_vm}/svcs.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"zpool status\"" > ${l_infra_dir_vm}/zpool-status.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"cat /etc/release\"" > ${l_infra_dir_vm}/etc/release
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"cat /etc/nsswitch.conf\"" > ${l_infra_dir_vm}/etc/nsswitch.conf
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"cat /etc/inittab\"" > ${l_infra_dir_vm}/etc/inittab
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"cat /etc/vfstab\"" > ${l_infra_dir_vm}/etc/vfstab
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"swap -l\"" > ${l_infra_dir_vm}/swap.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"psrinfo -pv\"" > ${l_infra_dir_vm}/psrinfo.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"prtconf\"" > ${l_infra_dir_vm}/prtconf.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"zpool list rpool\"" > ${l_infra_dir_vm}/zpool_list.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"psrset -Q 1\"" > ${l_infra_dir_vm}/psrset-Q_1.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"psrset -Q 2\"" > ${l_infra_dir_vm}/psrset-Q_2.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"zfs get all data\"" > ${l_infra_dir_vm}/zfs_get_data.txt
			rsh ${l_ldom_hostname} "zlogin ${l_infra_hostname} \"zfs get all http_logs\"" > ${l_infra_dir_vm}/zfs_get_http_logs.txt
		else
			echo "Connecting TILE$i via ${l_infra_hostname}"
			zlogin ${l_infra_hostname} "ifconfig -a" > ${l_infra_dir_vm}/ifconfig.txt
			zlogin ${l_infra_hostname} "pkg list -v" > ${l_infra_dir_vm}/pkglist.txt
			rcp g${l_infra_hostname}:/root/.rhosts ${l_infra_dir_vm}
			rcp g${l_infra_hostname}:/opt/oracle/webserver7/https-besim/start_it ${l_infra_dir_vm}/opt/oracle/webserver7/https-besim/start_it
			rcp g${l_infra_hostname}:/opt/oracle/webserver7/https-besim/config/magnus.conf ${l_infra_dir_sw}/opt/oracle/webserver7/https-besim/config/magnus.conf
			rcp g${l_infra_hostname}:/opt/oracle/webserver7/https-besim/config/obj.conf ${l_infra_dir_sw}/opt/oracle/webserver7/https-besim/config/obj.conf
			rcp g${l_infra_hostname}:/opt/oracle/webserver7/https-besim/config/server.xml ${l_infra_dir_sw}/opt/oracle/webserver7/https-besim/config/server.xml
			rcp g${l_infra_hostname}:/etc/hosts ${l_infra_dir_vm}/etc
			rcp g${l_infra_hostname}:/tmp/pollme.g${l_infra_hostname} ${l_infra_dir_vm}/tmp
			rcp g${l_infra_hostname}:/http_logs/errors ${l_infra_dir_logs}/infra_tile${i}_errors
			rcp g${l_infra_hostname}:/http_logs/access ${l_infra_dir_logs}/infra_tile${i}_access
			zlogin ${l_infra_hostname} "df -h" > ${l_infra_dir_vm}/df.txt
			zlogin ${l_infra_hostname} "hostname" > ${l_infra_dir_vm}/hostname.txt
			zlogin ${l_infra_hostname} "mount -v" > ${l_infra_dir_vm}/mount.txt
			zlogin ${l_infra_hostname} "ps -eaf" > ${l_infra_dir_vm}/ps-eaf.txt
			zlogin ${l_infra_hostname} "netstat -a" > ${l_infra_dir_vm}/netstat.txt
			zlogin ${l_infra_hostname} "uname" > ${l_infra_dir_vm}/uname.txt
			zlogin ${l_infra_hostname} "uptime" > ${l_infra_dir_vm}/uptime.txt
			zlogin ${l_infra_hostname} "dladm show-vnic" > ${l_infra_dir_vm}/dladm_show-vnic.txt
			zlogin ${l_infra_hostname} "svcs" > ${l_infra_dir_vm}/svcs.txt
			zlogin ${l_infra_hostname} "zpool status" > ${l_infra_dir_vm}/zpool-status.txt
			zlogin ${l_infra_hostname} "cat /etc/release" > ${l_infra_dir_vm}/etc/release
			zlogin ${l_infra_hostname} "cat /etc/nsswitch.conf" > ${l_infra_dir_vm}/etc/nsswitch.conf
			zlogin ${l_infra_hostname} "cat /etc/inittab" > ${l_infra_dir_vm}/etc/inittab
			zlogin ${l_infra_hostname} "cat /etc/vfstab" > ${l_infra_dir_vm}/etc/vfstab
			zlogin ${l_infra_hostname} "swap -l" > ${l_infra_dir_vm}/swap.txt
			zlogin ${l_infra_hostname} "psrinfo -pv" > ${l_infra_dir_vm}/psrinfo.txt
			zlogin ${l_infra_hostname} "prtconf" > ${l_infra_dir_vm}/prtconf.txt
			zlogin ${l_infra_hostname} "zpool list rpool" > ${l_infra_dir_vm}/zpool_list.txt
			zlogin ${l_infra_hostname} "zfs get all data" > ${l_infra_dir_vm}/zfs_get_data.txt
			zlogin ${l_infra_hostname} "zfs get all http_logs" > ${l_infra_dir_vm}/zfs_get_http_logs.txt
		fi
	done
	echo ""
}

function collect_db()
{
        if (($DEBUG_MODE == 1));
        then
                echo "collect db config"
        fi

#  return 0

	for i in $(eval echo $TILE_RANGE);
	do
	    if ((i%4==1))
	    then
		eval l_db_hostname=${DB_HOSTNAME[$((i-1))]}
                l_db_dir=${OUTPUT_DIR}/${OUTPUT_SUBDIR_L1}/${OUTPUT_SUBDIR_L2_2}/tile${i}/dbserver
		l_db_dir_vm=${l_db_dir}/VM_Configuration
		l_db_dir_sw=${l_db_dir}/Software_Configuration
		l_db_dir_logs=${OUTPUT_SUBDIR_LOGS}/dblogs
		mkdir -p ${l_db_dir_sw}/export/home/oracle
		mkdir -p ${l_db_dir_vm}/etc
		mkdir -p ${l_db_dir_vm}/tmp
		mkdir -p ${l_db_dir_logs}
		cp /etc/zones/${l_db_hostname}.xml ${l_db_dir}
		if (($IS_LDOM == 1))
		then
                        tile_map $i $DB
                        l_ldom_hostname=${LDOM_HOSTNAME[$ldomN]}
			#l_ldom_hostname=${LDOM_HOSTNAME[${TILE_TO_LDOM[$i]}]}
			echo "Connecting LDOM $l_ldom_hostname TILE$i ${l_db_hostname}"
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"ifconfig -a\"" > ${l_db_dir_vm}/ifconfig.txt
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"pkg list -v\"" > ${l_db_dir_vm}/pkglist.txt
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"cat /root/.rhosts\"" > ${l_db_dir_vm}/.rhosts 
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"cat /export/home/oracle/start_db.sh\"" > ${l_db_dir_sw}/export/home/oracle/start_db.sh
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"cat /export/home/oracle/stop_db.sh\"" > ${l_db_dir_sw}/export/home/oracle/stop_db.sh
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"cat /export/home/oracle/alert_specdb.log\"" > ${l_db_dir_logs}/db_tile${i}_alert_specdb.log
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"cat /export/home/oracle/alert+ASM.log\"" > ${l_db_dir_logs}/db_tile${i}_alert+ASM.log
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"cat /export/home/oracle/gather_asm.sh\"" > ${l_db_dir_sw}/export/home/oracle/gather_asm.sh
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"su - oracle -c ' /export/home/oracle/gather_asm.sh ' \" " > ${l_db_dir_sw}/asm_disk_output.txt.log
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"cat /export/home/oracle/app/oracle/product/12.1.0/dbhome_1/dbs/initspecdb.ora\"" > ${l_db_dir_sw}/export/home/oracle/initspecdb.ora
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"cat /etc/hosts\"" > ${l_db_dir_vm}/etc/hosts
                        rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"cat /tmp/pollme.g${l_db_hostname}\"" > ${l_db_dir_vm}/tmp/pollme.g${l_db_hostname}
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"df -h\"" > ${l_db_dir_vm}/df.txt
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"hostname\"" > ${l_db_dir_vm}/hostname.txt
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"mount -v\"" > ${l_db_dir_vm}/mount.txt
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"ps -eaf\"" > ${l_db_dir_vm}/ps-eaf.txt
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"ps -eaflc\"" > ${l_db_dir_vm}/ps-eaflc.txt
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"netstat -a\"" > ${l_db_dir_vm}/netstat.txt
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"uname\"" > ${l_db_dir_vm}/uname.txt
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"uptime\"" > ${l_db_dir_vm}/uptime.txt
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"dladm show-vnic\"" > ${l_db_dir_vm}/dladm_show-vnic.txt
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"svcs\"" > ${l_db_dir_vm}/svcs.txt
			rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"zpool status\"" > ${l_db_dir_vm}/zpool-status.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"cat /etc/release\"" > ${l_db_dir_vm}/etc/release
                        rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"cat /etc/nsswitch.conf\"" > ${l_db_dir_vm}/etc/nsswitch.conf
                        rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"cat /etc/inittab\"" > ${l_db_dir_vm}/etc/inittab
                        rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"cat /etc/vfstab\"" > ${l_db_dir_vm}/etc/vfstab
                        rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"swap -l\"" > ${l_db_dir_vm}/swap.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"psrinfo -pv\"" > ${l_db_dir_vm}/psrinfo.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"prtconf\"" > ${l_db_dir_vm}/prtconf.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"zpool list rpool\"" > ${l_db_dir_vm}/zpool_list.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"psrset -Q 1\"" > ${l_db_dir_vm}/psrset-Q_1.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_db_hostname} \"psrset -Q 2\"" > ${l_db_dir_vm}/psrset-Q_2.txt
		else
			echo "Connecting TILE$i via ${l_db_hostname}"
			zlogin ${l_db_hostname} "ifconfig -a" > ${l_db_dir_vm}/ifconfig.txt
			zlogin ${l_db_hostname} "pkg list -v" > ${l_db_dir_vm}/pkglist.txt
			rcp g${l_db_hostname}:/root/.rhosts ${l_db_dir_vm}
			rcp -r g${l_db_hostname}:/export/home/oracle/start_db.sh ${l_db_dir_sw}/export/home/oracle
			rcp -r g${l_db_hostname}:/export/home/oracle/stop_db.sh ${l_db_dir_sw}/export/home/oracle
			rcp -r g${l_db_hostname}:/export/home/oracle/alert_specdb.log ${l_db_dir_logs}/db_tile${i}_alert_specdb.log 
			rcp -r g${l_db_hostname}:/export/home/oracle/alert+ASM.log ${l_db_dir_logs}/db_tile${i}_alert+ASM.log

			rcp -r g${l_db_hostname}:/export/home/oracle/gather_asm.sh ${l_db_dir_sw}/export/home/oracle
			zlogin ${l_db_hostname} "su - oracle -c ' /export/home/oracle/gather_asm.sh ' \"" > ${l_db_dir_sw}/asm_disk_output.txt.log
			rcp -r g${l_db_hostname}:/export/home/oracle/app/oracle/product/12.1.0/dbhome_1/dbs/initspecdb.ora ${l_db_dir_sw}/export/home/oracle
			rcp -r g${l_db_hostname}:/export/home/oracle/app/oracle/product/12.1.0/grid/dbs/init+ASM.ora ${l_db_dir_sw}/export/home/oracle
			rcp g${l_db_hostname}:/etc/hosts ${l_db_dir_vm}/etc
			rcp g${l_db_hostname}:/tmp/pollme.g${l_db_hostname} ${l_db_dir_vm}/tmp
			zlogin ${l_db_hostname} "df -h" > ${l_db_dir_vm}/df.txt
			zlogin ${l_db_hostname} "hostname" > ${l_db_dir_vm}/hostname.txt
			zlogin ${l_db_hostname} "mount -v" > ${l_db_dir_vm}/mount.txt
			zlogin ${l_db_hostname} "ps -eaf" > ${l_db_dir_vm}/ps-eaf.txt
			zlogin ${l_db_hostname} "netstat -a" > ${l_db_dir_vm}/netstat.txt
			zlogin ${l_db_hostname} "uname" > ${l_db_dir_vm}/uname.txt
			zlogin ${l_db_hostname} "uptime" > ${l_db_dir_vm}/uptime.txt
			zlogin ${l_db_hostname} "dladm show-vnic" > ${l_db_dir_vm}/dladm_show-vnic.txt
			zlogin ${l_db_hostname} "svcs" > ${l_db_dir_vm}/svcs.txt
			zlogin ${l_db_hostname} "zpool status" > ${l_db_dir_vm}/zpool-status.txt
                        zlogin ${l_db_hostname} "cat /etc/release" > ${l_db_dir_vm}/etc/release
                        zlogin ${l_db_hostname} "cat /etc/nsswitch.conf" > ${l_db_dir_vm}/etc/nsswitch.conf
                        zlogin ${l_db_hostname} "cat /etc/inittab" > ${l_db_dir_vm}/etc/inittab
                        zlogin ${l_db_hostname} "cat /etc/vfstab" > ${l_db_dir_vm}/etc/vfstab
                        zlogin ${l_db_hostname} "swap -l" > ${l_db_dir_vm}/swap.txt
                        zlogin ${l_db_hostname} "psrinfo -pv" > ${l_db_dir_vm}/psrinfo.txt
                        zlogin ${l_db_hostname} "prtconf" > ${l_db_dir_vm}/prtconf.txt
                        zlogin ${l_db_hostname} "zpool list rpool" > ${l_db_dir_vm}/zpool_list.txt
		fi
	    fi
	done
	echo ""
}

function collect_japp()
{
        if (($DEBUG_MODE == 1));
        then
                echo "collect japp config"
        fi

#return 0

	for i in $(eval echo $TILE_RANGE);
	do
		eval l_japp_hostname=${JAPP_HOSTNAME[$((i-1))]}
		l_japp_dir=${OUTPUT_DIR}/${OUTPUT_SUBDIR_L1}/${OUTPUT_SUBDIR_L2_2}/tile${i}/appserver
		l_japp_dir_vm=${l_japp_dir}/VM_Configuration
		l_japp_dir_sw=${l_japp_dir}/Software_Configuration
		l_japp_dir_logs=${OUTPUT_SUBDIR_LOGS}/applogs
		mkdir -p ${l_japp_dir_sw}/export/home/oracle/user_domains/jasdomain-1/config/jms
		mkdir -p ${l_japp_dir_sw}/export/home/oracle/user_domains/jasdomain-1/config/jdbc
		mkdir -p ${l_japp_dir_sw}/export/home/oracle/user_domains/jasdomain-1/applications
		mkdir -p ${l_japp_dir_sw}/export/home/oracle/user_domains/emulatordomain/config
		mkdir -p ${l_japp_dir_vm}/etc
		mkdir -p ${l_japp_dir_vm}/tmp
		mkdir -p ${l_japp_dir_logs}
		cp /etc/zones/${l_japp_hostname}.xml ${l_japp_dir}
		if (($IS_LDOM == 1))
		then
			tile_map $i $JAPP
                        l_ldom_hostname=${LDOM_HOSTNAME[$ldomN]}
			#l_ldom_hostname=${LDOM_HOSTNAME[${TILE_TO_LDOM[$i]}]}
                        echo "Connecting LDOM $l_ldom_hostname TILE$i ${l_japp_hostname}"
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"ifconfig -a\"" > ${l_japp_dir_vm}/ifconfig.txt
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"pkg list -v\"" > ${l_japp_dir_vm}/pkglist.txt
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /root/.rhosts\"" > ${l_japp_dir_vm}/.rhosts 
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /export/home/oracle/user_domains/init.sh\"" > ${l_japp_dir_sw}/export/home/oracle/user_domains/init.sh
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /export/home/oracle/user_domains/jasdomain-1/startWebLogic.sh\"" > ${l_japp_dir_sw}/export/home/oracle/user_domains/jasdomain-1/startWebLogic.sh
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /export/home/oracle/user_domains/jasdomain-1/setEnv.sh\"" > ${l_japp_dir_sw}/export/home/oracle/user_domains/jasdomain-1/setEnv.sh
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /export/home/oracle/user_domains/jasdomain-1/weblogic.log\"" > ${l_japp_dir_logs}/app_tile${i}_jasdomain-1_weblogic.log
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /export/home/oracle/user_domains/jasdomain-1/config/config.xml\"" > ${l_japp_dir_sw}/export/home/oracle/user_domains/jasdomain-1/config/config.xml
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /export/home/oracle/user_domains/emulatordomain/setEnv.sh\"" > ${l_japp_dir_sw}/export/home/oracle/user_domains/emulatordomain/setEnv.sh
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /export/home/oracle/user_domains/emulatordomain/startWebLogic.sh\"" > ${l_japp_dir_sw}/export/home/oracle/user_domains/emulatordomain/startWebLogic.sh
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /export/home/oracle/user_domains/emulatordomain/weblogic.log\"" > ${l_japp_dir_logs}/app_tile${i}_emulatordomain_weblogic.log
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /export/home/oracle/user_domains/emulatordomain/config/config.xml\"" > ${l_japp_dir_sw}/export/home/oracle/user_domains/emulatordomain/config/config.xml
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /etc/hosts\"" > ${l_japp_dir_vm}/etc/hosts
                        rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /tmp/pollme.g${l_japp_hostname}\"" > ${l_japp_dir_vm}/tmp/pollme.g${l_japp_hostname}
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"df -h\"" > ${l_japp_dir_vm}/df.txt
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"hostname\"" > ${l_japp_dir_vm}/hostname.txt
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"mount -v\"" > ${l_japp_dir_vm}/mount.txt
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"ps -eaf\"" > ${l_japp_dir_vm}/ps-eaf.txt
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"ps -eaflc\"" > ${l_japp_dir_vm}/ps-eaflc.txt
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"netstat -a\"" > ${l_japp_dir_vm}/netstat.txt
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"uname\"" > ${l_japp_dir_vm}/uname.txt
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"uptime\"" > ${l_japp_dir_vm}/uptime.txt
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"dladm show-vnic\"" > ${l_japp_dir_vm}/dladm_show-vnic.txt
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"svcs\"" > ${l_japp_dir_vm}/svcs.txt
			rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"zpool status\"" > ${l_japp_dir_vm}/zpool-status.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /etc/release\"" > ${l_japp_dir_vm}/etc/release
                        rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /etc/nsswitch.conf\"" > ${l_japp_dir_vm}/etc/nsswitch.conf
                        rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /etc/inittab\"" > ${l_japp_dir_vm}/etc/inittab
                        rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /etc/vfstab\"" > ${l_japp_dir_vm}/etc/vfstab
                        rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"swap -l\"" > ${l_japp_dir_vm}/swap.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"psrinfo -pv\"" > ${l_japp_dir_vm}/psrinfo.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"java -version\"" 2> ${l_japp_dir_sw}/java_version.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /export/home/oracle/user_domains/jasdomain-1/config/jms/interop-jms.xml\"" > ${l_japp_dir_sw}/export/home/oracle/user_domains/jasdomain-1/config/jms/interop-jms.xml
                        rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /export/home/oracle/user_domains/jasdomain-1/config/jdbc/CP-auditConnectionPool-jdbc.xml\"" > ${l_japp_dir_sw}/export/home/oracle/user_domains/jasdomain-1/config/jdbc/CP-auditConnectionPool-jdbc.xml
                        rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /export/home/oracle/user_domains/jasdomain-1/config/jdbc/CP-specConnectionPool-jdbc.xml\"" > ${l_japp_dir_sw}/export/home/oracle/user_domains/jasdomain-1/config/jdbc/CP-specConnectionPool-jdbc.xml
                        rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"cat /export/home/oracle/user_domains/jasdomain-1/applications/SPECjAppServer.ear\"" > ${l_japp_dir_sw}/export/home/oracle/user_domains/jasdomain-1/applications/SPECjAppServer.ear
                        rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"prtconf\"" > ${l_japp_dir_sw}/prtconf.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"zpool list rpool\"" > ${l_japp_dir_sw}/zpool_list.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"psrset -Q 1\"" > ${l_japp_dir_sw}/psrset-Q_1.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"psrset -Q 2\"" > ${l_japp_dir_sw}/psrset-Q_2.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_japp_hostname} \"zfs get all jms\"" > ${l_japp_dir_sw}/zfs_get_jms.txt
		else
			echo "Connecting TILE$i via ${l_japp_hostname}"
			zlogin ${l_japp_hostname} "ifconfig -a" > ${l_japp_dir_vm}/ifconfig.txt
			zlogin ${l_japp_hostname} "pkg list -v" > ${l_japp_dir_vm}/pkglist.txt
			rcp g${l_japp_hostname}:/root/.rhosts ${l_japp_dir_vm}
			rcp -r g${l_japp_hostname}:/export/home/oracle/user_domains/init.sh ${l_japp_dir_sw}/export/home/oracle/user_domains
			rcp -r g${l_japp_hostname}:/export/home/oracle/user_domains/jasdomain-1/startWebLogic.sh ${l_japp_dir_sw}/export/home/oracle/user_domains/jasdomain-1
			rcp -r g${l_japp_hostname}:/export/home/oracle/user_domains/jasdomain-1/setEnv.sh ${l_japp_dir_sw}/export/home/oracle/user_domains/jasdomain-1
			rcp -r g${l_japp_hostname}:/export/home/oracle/user_domains/jasdomain-1/weblogic.log ${l_japp_dir_logs}/app_tile${i}_jasdomain-1_weblogic.log
			rcp -r g${l_japp_hostname}:/export/home/oracle/user_domains/jasdomain-1/config/config.xml ${l_japp_dir_sw}/export/home/oracle/user_domains/jasdomain-1/config
			rcp -r g${l_japp_hostname}:/export/home/oracle/user_domains/emulatordomain/setEnv.sh ${l_japp_dir_sw}/export/home/oracle/user_domains/emulatordomain
			rcp -r g${l_japp_hostname}:/export/home/oracle/user_domains/emulatordomain/startWebLogic.sh ${l_japp_dir_sw}/export/home/oracle/user_domains/emulatordomain
			rcp -r g${l_japp_hostname}:/export/home/oracle/user_domains/emulatordomain/weblogic.log ${l_japp_dir_logs}/app_tile${i}_emulatordomain_weblogic.log
			rcp -r g${l_japp_hostname}:/export/home/oracle/user_domains/emulatordomain/config/config.xml ${l_japp_dir_sw}/export/home/oracle/user_domains/emulatordomain/config
			rcp g${l_japp_hostname}:/etc/hosts ${l_japp_dir_vm}/etc
			rcp g${l_japp_hostname}:/tmp/pollme.g${l_japp_hostname} ${l_japp_dir_vm}/tmp
			zlogin ${l_japp_hostname} "df -h" > ${l_japp_dir_vm}/df.txt
			zlogin ${l_japp_hostname} "hostname" > ${l_japp_dir_vm}/hostname.txt
			zlogin ${l_japp_hostname} "mount -v" > ${l_japp_dir_vm}/mount.txt
			zlogin ${l_japp_hostname} "ps -eaf" > ${l_japp_dir_vm}/ps-eaf.txt
			zlogin ${l_japp_hostname} "netstat -a" > ${l_japp_dir_vm}/netstat.txt
			zlogin ${l_japp_hostname} "uname" > ${l_japp_dir_vm}/uname.txt
			zlogin ${l_japp_hostname} "uptime" > ${l_japp_dir_vm}/uptime.txt
			zlogin ${l_japp_hostname} "dladm show-vnic" > ${l_japp_dir_vm}/dladm_show-vnic.txt
			zlogin ${l_japp_hostname} "svcs" > ${l_japp_dir_vm}/svcs.txt
			zlogin ${l_japp_hostname} "zpool status" > ${l_japp_dir_vm}/zpool-status.txt
                        zlogin ${l_japp_hostname} "cat /etc/release" > ${l_japp_dir_vm}/etc/release
                        zlogin ${l_japp_hostname} "cat /etc/nsswitch.conf" > ${l_japp_dir_vm}/etc/nsswitch.conf
                        zlogin ${l_japp_hostname} "cat /etc/inittab" > ${l_japp_dir_vm}/etc/inittab
                        zlogin ${l_japp_hostname} "cat /etc/vfstab" > ${l_japp_dir_vm}/etc/vfstab
                        zlogin ${l_japp_hostname} "swap -l" > ${l_japp_dir_vm}/swap.txt
                        zlogin ${l_japp_hostname} "psrinfo -pv" > ${l_japp_dir_vm}/psrinfo.txt
                        zlogin ${l_japp_hostname} "java -version" 2> ${l_japp_dir_vm}/java_version.txt
                        zlogin ${l_japp_hostname} "cat /export/home/oracle/user_domains/jasdomain-1/config/jms/interop-jms.xml" > ${l_japp_dir_sw}/export/home/oracle/user_domains/jasdomain-1/config/jms/interop-jms.xml
                        zlogin ${l_japp_hostname} "cat /export/home/oracle/user_domains/jasdomain-1/config/jdbc/CP-auditConnectionPool-jdbc.xml" > ${l_japp_dir_sw}/export/home/oracle/user_domains/jasdomain-1/config/jdbc/CP-auditConnectionPool-jdbc.xml
                        zlogin ${l_japp_hostname} "cat /export/home/oracle/user_domains/jasdomain-1/config/jdbc/CP-specConnectionPool-jdbc.xml" > ${l_japp_dir_sw}/export/home/oracle/user_domains/jasdomain-1/config/jdbc/CP-specConnectionPool-jdbc.xml
                        zlogin ${l_japp_hostname} "cat /export/home/oracle/user_domains/jasdomain-1/applications/SPECjAppServer.ear" > ${l_japp_dir_sw}/export/home/oracle/user_domains/jasdomain-1/applications/SPECjAppServer.ear
                        zlogin ${l_japp_hostname} "prtconf" > ${l_japp_dir_vm}/prtconf.txt
                        zlogin ${l_japp_hostname} "zpool list rpool" > ${l_japp_dir_vm}/zpool_list.txt
                        zlogin ${l_japp_hostname} "zfs get all jms" > ${l_japp_dir_vm}/zfs_get_jms.txt
		fi
	done

	echo ""
}

function collect_mail()
{
        if (($DEBUG_MODE == 1));
        then
                echo "collect mail config"
        fi

#return 0

	for i in $(eval echo $TILE_RANGE);
	do
		eval l_mail_hostname=${MAIL_HOSTNAME[$((i-1))]}
                l_mail_dir=${OUTPUT_DIR}/${OUTPUT_SUBDIR_L1}/${OUTPUT_SUBDIR_L2_2}/tile${i}/mailserver
		l_mail_dir_vm=${l_mail_dir}/VM_Configuration
		l_mail_dir_sw=${l_mail_dir}/Software_Configuration
		l_mail_dir_logs=${OUTPUT_SUBDIR_LOGS}/maillogs
		mkdir -p ${l_mail_dir_sw}/export/home/dovecot
		mkdir -p ${l_mail_dir_vm}/etc
		mkdir -p ${l_mail_dir_vm}/tmp
		mkdir -p ${l_mail_dir_logs}
		cp /etc/zones/${l_mail_hostname}.xml ${l_mail_dir}
		if (($IS_LDOM == 1))
		then
			tile_map $i $MAIL
                        l_ldom_hostname=${LDOM_HOSTNAME[$ldomN]}
			#l_ldom_hostname=${LDOM_HOSTNAME[${TILE_TO_LDOM[$i]}]}
                        echo "Connecting LDOM $l_ldom_hostname TILE$i ${l_mail_hostname}"
			rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"ifconfig -a\"" > ${l_mail_dir_vm}/ifconfig.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"pkg list -v\"" > ${l_mail_dir_vm}/pkglist.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"cat /root/.rhosts\"" > ${l_mail_dir_vm}/.rhosts
                        rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"cat /export/home/dovecot/start_FX.xx_logging\"" > ${l_mail_dir_sw}/export/home/dovecot/start_FX.xx_logging
                        rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"cat /export/home/dovecot/dovecot.conf_logging\"" > ${l_mail_dir_sw}/export/home/dovecot/dovecot.conf_logging
			rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"cat /etc/hosts\"" > ${l_mail_dir_vm}/etc/hosts
                        rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"cat /tmp/pollme.g${l_mail_hostname}\"" > ${l_mail_dir_vm}/tmp/pollme.g${l_mail_hostname}
			rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"cat /mail_logs/dovecot.log\"" > ${l_mail_dir_logs}/mail_tile${i}_dovecot.log
			rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"cat /mail_logs/debug_info_dovecot.log\"" > ${l_mail_dir_logs}/mail_tile${i}_debug_info_dovecot.log 
			rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"df -h\"" > ${l_mail_dir_vm}/df.txt
			rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"hostname\"" > ${l_mail_dir_vm}/hostname.txt
			rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"mount -v\"" > ${l_mail_dir_vm}/mount.txt
			rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"ps -eaf\"" > ${l_mail_dir_vm}/ps-eaf.txt
			rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"ps -eaflc\"" > ${l_mail_dir_vm}/ps-eaflc.txt
			rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"netstat -a\"" > ${l_mail_dir_vm}/netstat.txt
			rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"uname\"" > ${l_mail_dir_vm}/uname.txt
			rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"uptime\"" > ${l_mail_dir_vm}/uptime.txt
			rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"dladm show-vnic\"" > ${l_mail_dir_vm}/dladm_show-vnic.txt
			rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"svcs\"" > ${l_mail_dir_vm}/svcs.txt
			rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"zpool status\"" > ${l_mail_dir_vm}/zpool-status.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"cat /etc/release\"" > ${l_mail_dir_vm}/etc/release
                        rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"cat /etc/nsswitch.conf\"" > ${l_mail_dir_vm}/etc/nsswitch.conf
                        rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"cat /etc/inittab\"" > ${l_mail_dir_vm}/etc/inittab
                        rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"cat /etc/vfstab\"" > ${l_mail_dir_vm}/etc/vfstab
                        rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"swap -l\"" > ${l_mail_dir_vm}/swap.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"psrinfo -pv\"" > ${l_mail_dir_vm}/psrinfo.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"prtconf\"" > ${l_mail_dir_vm}/prtconf.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"zpool list rpool\"" > ${l_mail_dir_vm}/zpool_list.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"psrset -Q 1\"" > ${l_mail_dir_vm}/psrset-Q_1.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"psrset -Q 2\"" > ${l_mail_dir_vm}/psrset-Q_2.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"zfs get all data\"" > ${l_mail_dir_vm}/zfs_get_data.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_mail_hostname} \"zfs get all mail_logs\"" > ${l_mail_dir_vm}/zfs_get_mail_logs.txt
		else
			echo "Connecting TILE$i via ${l_mail_hostname}"
			zlogin ${l_mail_hostname} "ifconfig -a" > ${l_mail_dir_vm}/ifconfig.txt
			zlogin ${l_mail_hostname} "pkg list -v" > ${l_mail_dir_vm}/pkglist.txt
			rcp g${l_mail_hostname}:/root/.rhosts ${l_mail_dir_vm}
			rcp -r g${l_mail_hostname}:/export/home/dovecot/start_FX.xx_logging ${l_mail_dir_sw}/export/home/dovecot
			rcp -r g${l_mail_hostname}:/export/home/dovecot/dovecot.conf_logging ${l_mail_dir_sw}/export/home/dovecot
			rcp g${l_mail_hostname}:/etc/hosts ${l_mail_dir_vm}/etc
			rcp g${l_mail_hostname}:/tmp/pollme.g${l_mail_hostname} ${l_mail_dir_vm}/tmp
			rcp g${l_mail_hostname}:/mail_logs/dovecot.log ${l_mail_dir_vm}/mail_logs
			#rcp g${l_mail_hostname}:/mail_logs/debug_info_dovecot.log ${l_mail_dir_vm}/mail_logs
			zlogin ${l_mail_hostname} "df -h" > ${l_mail_dir_vm}/df.txt
			zlogin ${l_mail_hostname} "hostname" > ${l_mail_dir_vm}/hostname.txt
			zlogin ${l_mail_hostname} "mount -v" > ${l_mail_dir_vm}/mount.txt
			zlogin ${l_mail_hostname} "ps -eaf" > ${l_mail_dir_vm}/ps-eaf.txt
			zlogin ${l_mail_hostname} "netstat -a" > ${l_mail_dir_vm}/netstat.txt
			zlogin ${l_mail_hostname} "uname" > ${l_mail_dir_vm}/uname.txt
			zlogin ${l_mail_hostname} "uptime" > ${l_mail_dir_vm}/uptime.txt
			zlogin ${l_mail_hostname} "dladm show-vnic" > ${l_mail_dir_vm}/dladm_show-vnic.txt
			zlogin ${l_mail_hostname} "svcs" > ${l_mail_dir_vm}/svcs.txt
			zlogin ${l_mail_hostname} "zpool status" > ${l_mail_dir_vm}/zpool-status.txt
                        zlogin ${l_mail_hostname} "cat /etc/release" > ${l_mail_dir_vm}/etc/release
                        zlogin ${l_mail_hostname} "cat /etc/nsswitch.conf" > ${l_mail_dir_vm}/etc/nsswitch.conf
                        zlogin ${l_mail_hostname} "cat /etc/inittab" > ${l_mail_dir_vm}/etc/inittab
                        zlogin ${l_mail_hostname} "cat /etc/vfstab" > ${l_mail_dir_vm}/etc/vfstab
                        zlogin ${l_mail_hostname} "swap -l" > ${l_mail_dir_vm}/swap.txt
                        zlogin ${l_mail_hostname} "psrinfo -pv" > ${l_mail_dir_vm}/psrinfo.txt
                        zlogin ${l_mail_hostname} "prtconf" > ${l_mail_dir_vm}/prtconf.txt
                        zlogin ${l_mail_hostname} "zpool list rpool" > ${l_mail_dir_vm}/zpool_list.txt
                        zlogin ${l_mail_hostname} "zfs get all data" > ${l_mail_dir_vm}/zfs_get_data.txt
                        zlogin ${l_mail_hostname} "zfs get all mail_logs" > ${l_mail_dir_vm}/zfs_get_mail_logs.txt
		fi	
	done

	echo ""
}

function collect_batch()
{
        if (($DEBUG_MODE == 1));
        then
                echo "collect batch config"
          for i in $(eval echo $TILE_RANGE);
          do
            if (($IS_LDOM == 1))
            then
                l_ldom_hostname=${LDOM_HOSTNAME[${TILE_TO_LDOM[$i]}]}
                 echo "Connecting LDOM $l_ldom_hostname TILE$i ${l_batch_hostname}"
            fi
          done

        fi

#return 0

	for i in $(eval echo $TILE_RANGE);
	do
		eval l_batch_hostname=${BATCH_HOSTNAME[$((i-1))]}
                l_batch_dir=${OUTPUT_DIR}/${OUTPUT_SUBDIR_L1}/${OUTPUT_SUBDIR_L2_2}/tile${i}/batchserver
		l_batch_dir_vm=${l_batch_dir}/VM_Configuration
		l_batch_dir_sw=${l_batch_dir}/Software_Configuration
		mkdir -p ${l_batch_dir_vm}/etc
		mkdir -p ${l_batch_dir_vm}/tmp
		mkdir -p ${l_batch_dir_sw}/SPECbatch/cpu2006
		cp /etc/zones/${l_batch_hostname}.xml ${l_batch_dir}
		if (($IS_LDOM == 1))
		then
			tile_map $i $BATCH
                        l_ldom_hostname=${LDOM_HOSTNAME[$ldomN]}
			#l_ldom_hostname=${LDOM_HOSTNAME[${TILE_TO_LDOM[$i]}]}
                        echo "Connecting LDOM $l_ldom_hostname TILE$i ${l_batch_hostname}"
                        rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"java -version\"" 2> ${l_batch_dir_sw}/java_version.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"java -jar /export/home/specvirt/SPECpoll/pollme.jar -v\"" > ${l_batch_dir_sw}/SPECbatch/SPECpollVersion.out
                        rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"cat /export/home/specvirt/SPECbatch/Test.config\"" > ${l_batch_dir_sw}/SPECbatch/cpu2006/Test.config
                        rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"cat /export/home/specvirt/SPECbatch/cpu2006-virt/config/cpu2006-virt_17Apr2014_T1.cfg\"" > ${l_batch_dir_sw}/SPECbatch/cpu2006/cpu2006-virt_17Apr2014_T1.cfg
                        rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"cat /export/home/specvirt/SPECbatch/virt_sc2013_run.sh\"" > ${l_batch_dir_sw}/SPECbatch/cpu2006/virt_sc2013_run.sh
			rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"ifconfig -a\"" > ${l_batch_dir_vm}/ifconfig.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"pkg list -v\"" > ${l_batch_dir_vm}/pkglist.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"cat /root/.rhosts\"" > ${l_batch_dir_vm}/.rhosts
			rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"cat /etc/hosts\"" > ${l_batch_dir_vm}/etc/hosts
                        rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"cat /tmp/pollme.g${l_batch_hostname}\"" > ${l_batch_dir_vm}/tmp/pollme.g${l_batch_hostname}
			rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"df -h\"" > ${l_batch_dir_vm}/df.txt
			rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"hostname\"" > ${l_batch_dir_vm}/hostname.txt
			rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"mount -v\"" > ${l_batch_dir_vm}/mount.txt
			rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"ps -eaf\"" > ${l_batch_dir_vm}/ps-eaf.txt
			rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"ps -eaflc\"" > ${l_batch_dir_vm}/ps-eaflc.txt
			rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"netstat -a\"" > ${l_batch_dir_vm}/netstat.txt
			rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"uname\"" > ${l_batch_dir_vm}/uname.txt
			rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"uptime\"" > ${l_batch_dir_vm}/uptime.txt
			rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"dladm show-vnic\"" > ${l_batch_dir_vm}/dladm_show-vnic.txt
			rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"svcs\"" > ${l_batch_dir_vm}/svcs.txt
			rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"zpool status\"" > ${l_batch_dir_vm}/zpool-status.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"cat /etc/release\"" > ${l_batch_dir_vm}/etc/release
                        rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"cat /etc/nsswitch.conf\"" > ${l_batch_dir_vm}/etc/nsswitch.conf
                        rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"cat /etc/inittab\"" > ${l_batch_dir_vm}/etc/inittab
                        rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"cat /etc/vfstab\"" > ${l_batch_dir_vm}/etc/vfstab
                        rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"swap -l\"" > ${l_batch_dir_vm}/swap.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"psrinfo -pv\"" > ${l_batch_dir_vm}/psrinfo.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"prtconf\"" > ${l_batch_dir_vm}/prtconf.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"zpool list rpool\"" > ${l_batch_dir_vm}/zpool_list.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"psrset -Q 1\"" > ${l_batch_dir_vm}/psrset-Q_1.txt
                        rsh ${l_ldom_hostname} "zlogin ${l_batch_hostname} \"psrset -Q 2\"" > ${l_batch_dir_vm}/psrset-Q_2.txt
		else
			echo "Connecting TILE$i via ${l_batch_hostname}"
                        zlogin ${l_batch_hostname} "java -version" 2> ${l_batch_dir_sw}/java_version.txt
                        zlogin ${l_batch_hostname} java -jar /export/home/specvirt/SPECpoll/pollme.jar -v > ${l_batch_dir_sw}/SPECbatch/SPECpollVersion.out
                        rcp g${l_batch_hostname}:/export/home/specvirt/SPECbatch/Test.config ${l_batch_dir_sw}/SPECbatch/cpu2006
                        rcp g${l_batch_hostname}:/export/home/specvirt/SPECbatch/cpu2006-virt/config/cpu2006-virt_17Apr2014_T1.cfg ${l_batch_dir_sw}/SPECbatch/cpu2006
                        rcp g${l_batch_hostname}:/export/home/specvirt/SPECbatch/virt_sc2013_run.sh ${l_batch_dir_sw}/SPECbatch/cpu2006
			zlogin ${l_batch_hostname} "ifconfig -a" > ${l_batch_dir_vm}/ifconfig.txt
			zlogin ${l_batch_hostname} "pkg list -v" > ${l_batch_dir_vm}/pkglist.txt
			rcp g${l_batch_hostname}:/root/.rhosts ${l_batch_dir_vm}
			rcp g${l_batch_hostname}:/etc/hosts ${l_batch_dir_vm}/etc
			rcp g${l_batch_hostname}:/tmp/pollme.g${l_batch_hostname} ${l_batch_dir_vm}/tmp
			zlogin ${l_batch_hostname} "df -h" > ${l_batch_dir_vm}/df.txt
			zlogin ${l_batch_hostname} "hostname" > ${l_batch_dir_vm}/hostname.txt
			zlogin ${l_batch_hostname} "mount -v" > ${l_batch_dir_vm}/mount.txt
			zlogin ${l_batch_hostname} "ps -eaf" > ${l_batch_dir_vm}/ps-eaf.txt
			zlogin ${l_batch_hostname} "netstat -a" > ${l_batch_dir_vm}/netstat.txt
			zlogin ${l_batch_hostname} "uname" > ${l_batch_dir_vm}/uname.txt
			zlogin ${l_batch_hostname} "uptime" > ${l_batch_dir_vm}/uptime.txt
			zlogin ${l_batch_hostname} "dladm show-vnic" > ${l_batch_dir_vm}/dladm_show-vnic.txt
			zlogin ${l_batch_hostname} "svcs" > ${l_batch_dir_vm}/svcs.txt
			zlogin ${l_batch_hostname} "zpool status" > ${l_batch_dir_vm}/zpool-status.txt
                        zlogin ${l_batch_hostname} "cat /etc/release" > ${l_batch_dir_vm}/etc/release
                        zlogin ${l_batch_hostname} "cat /etc/nsswitch.conf" > ${l_batch_dir_vm}/etc/nsswitch.conf
                        zlogin ${l_batch_hostname} "cat /etc/inittab" > ${l_batch_dir_vm}/etc/inittab
                        zlogin ${l_batch_hostname} "cat /etc/vfstab" > ${l_batch_dir_vm}/etc/vfstab
                        zlogin ${l_batch_hostname} "swap -l" > ${l_batch_dir_vm}/swap.txt
                        zlogin ${l_batch_hostname} "psrinfo -pv" > ${l_batch_dir_vm}/psrinfo.txt
                        zlogin ${l_batch_hostname} "prtconf" > ${l_batch_dir_vm}/prtconf.txt
                        zlogin ${l_batch_hostname} "zpool list rpool" > ${l_batch_dir_vm}/zpool_list.txt
		fi
	done

	echo ""
}

function collect_client()
{
        if (($DEBUG_MODE == 1));
        then
                echo "collect client config"
        fi

#return 0

	for ((i=1; i<=${CLIENT_NUM}; i++));
	do
		eval l_client_hostname=${CLIENT_HOSTNAME[$((i-1))]}
		echo "Connecting CLIENT${i} via ${l_client_hostname}"
		l_client_dir=${OUTPUT_DIR}/${OUTPUT_SUBDIR_L1}/${OUTPUT_SUBDIR_L2_1}/clients/client${i}
		mkdir -p ${l_client_dir}/etc/rc2.d
		mkdir -p ${l_client_dir}/kernel/drv
		rsh ${l_client_hostname} "ifconfig -a" >  ${l_client_dir}/ifconfig.txt
		rsh ${l_client_hostname} "pkginfo" >  ${l_client_dir}/pkginfo.txt
		rcp ${l_client_hostname}:/etc/system ${l_client_dir}/etc
		rcp ${l_client_hostname}:/etc/hosts ${l_client_dir}/etc
		rcp ${l_client_hostname}:/etc/path_to_inst ${l_client_dir}/etc
		rcp ${l_client_hostname}:/etc/rc2.d/S99spec ${l_client_dir}/etc/rc2.d
		rcp ${l_client_hostname}:/kernel/drv/ixgbe.conf ${l_client_dir}/kernel/drv
		rsh ${l_client_hostname} "prtconf" > ${l_client_dir}/prtconf.txt
		rsh ${l_client_hostname} "df -h" > ${l_client_dir}/df.txt
		rsh ${l_client_hostname} "hostname" > ${l_client_dir}/hostname.txt
		rsh ${l_client_hostname} "mount -v" > ${l_client_dir}/mount.txt
		rsh ${l_client_hostname} "ps -eaf" > ${l_client_dir}/ps-eaf.txt
		rsh ${l_client_hostname} "ps -eaflc" > ${l_client_dir}/ps-eaflc.txt
		rsh ${l_client_hostname} "netstat -a" > ${l_client_dir}/netstat.txt
		rsh ${l_client_hostname} "uname" > ${l_client_dir}/uname.txt
		rsh ${l_client_hostname} "uptime" > ${l_client_dir}/uptime.txt
		rsh ${l_client_hostname} "svcs" > ${l_client_dir}/svcs.txt
		rsh ${l_client_hostname} "zpool status" > ${l_client_dir}/zpool-status.txt
	#	rsh ${l_client_hostname} "dladm show-etherstub" > ${l_client_dir}/dladm_show-etherstub.txt
	#	rsh ${l_client_hostname} "dladm show-vnic" > ${l_client_dir}/dladm_show-vnic.txt
		rsh ${l_client_hostname} "cat /etc/release" > ${l_client_dir}/etc/release
		rsh ${l_client_hostname} "cat /etc/nsswitch.conf" > ${l_client_dir}/etc/nsswitch.conf
		rsh ${l_client_hostname} "cat /etc/inittab" > ${l_client_dir}/etc/inittab
		rsh ${l_client_hostname} "cat /etc/vfstab" > ${l_client_dir}/etc/vfstab
		rsh ${l_client_hostname} "swap -l" > ${l_client_dir}/swap.txt
		rsh ${l_client_hostname} "psrinfo -pv" > ${l_client_dir}/psrinfo.txt
	done
	echo ""
}

function collect_sut()
{
        if (($DEBUG_MODE == 1));
        then
                echo "collect sut config"
        fi

#return 0

	l_sut_dir=${OUTPUT_DIR}/${OUTPUT_SUBDIR_L1}/${OUTPUT_SUBDIR_L2_1}/system-under-test
	mkdir -p ${l_sut_dir}/etc
	mkdir -p ${l_sut_dir}/kernel/drv
	cp /etc/system /etc/hosts ${l_sut_dir}/etc
	cp /kernel/drv/ixgbe.conf /kernel/drv/pcieb.conf ${l_sut_dir}/kernel/drv
	cp /etc/path_to_inst ${l_sut_dir}/etc
	ifconfig -a > ${l_sut_dir}/ifconfig.txt
	pkg list -v > ${l_sut_dir}/pkglist.txt
	ldm list > ${l_sut_dir}/ldm_list.txt
	ldm list-bindings > ${l_sut_dir}/ldm_list_bindings.txt
	prtconf > ${l_sut_dir}/prtconf.txt
	dladm show-etherstub > ${l_sut_dir}/dladm_show-etherstub.txt
	metastat -a > ${l_sut_dir}/metastat.txt
	df -h > ${l_sut_dir}/df.txt
	hostname > ${l_sut_dir}/hostname.txt
	mount -v > ${l_sut_dir}/mount.txt
	ps -eaf > ${l_sut_dir}/ps-eaf.txt
	ps -eaflc > ${l_sut_dir}/ps-eaflc.txt
	netstat -a > ${l_sut_dir}/netstat.txt
	uname > ${l_sut_dir}/uname.txt
	uptime > ${l_sut_dir}/uptime.txt
	dladm show-vnic > ${l_sut_dir}/dladm_show-vnic.txt
	svcs > ${l_sut_dir}/svcs.txt
	zpool status > ${l_sut_dir}/zpool-status.txt
	cp /etc/release ${l_sut_dir}/etc/release
	cp /etc/nsswitch.conf ${l_sut_dir}/etc/nsswitch.conf
	cp /etc/inittab ${l_sut_dir}/etc/inittab
	cp /etc/vfstab ${l_sut_dir}/etc/vfstab
	swap -l > ${l_sut_dir}/swap.txt
	psrinfo -pv > ${l_sut_dir}/psrinfo.txt
	if ((IS_LDOM == 0));
	then
		mkdir -p ${l_sut_dir}/etc/zones
		for vm in $(eval echo $VM_RANGE);
		do
			VM=$(echo $vm | tr [a-z] [A-Z])
			for i in $(eval echo $TILE_RANGE);
       			do
				if [ $vm = 'db' ]
				then
					if ((i%4==1))
					then
               					eval cp /etc/zones/$(echo \${${VM}_HOSTNAME[$((i-1))]}).xml ${l_sut_dir}/etc/zones
					fi
				else
               					eval cp /etc/zones/$(echo \${${VM}_HOSTNAME[$((i-1))]}).xml ${l_sut_dir}/etc/zones
				fi
       			done
               		cp /etc/zones/${vm}master.xml ${l_sut_dir}/etc/zones
		done
	fi
	echo ""
}

function collect_ldom()
{
        if (($DEBUG_MODE == 1));
        then
                echo "collect LDOM config"
        fi

#return 0

	for ((i=0; i<${LDOM_NUM}; i++))
	do
		l_ldom_hostname=${LDOM_HOSTNAME[$i]}
		echo "Connecting LDOM$((i+1)) via ${l_ldom_hostname}"
		l_ldom_dir=${OUTPUT_DIR}/${OUTPUT_SUBDIR_L1}/${OUTPUT_SUBDIR_L2_2}/LDOM$((i+1))
		mkdir -p ${l_ldom_dir}/etc/zones
		mkdir -p ${l_ldom_dir}/etc/rc2.d
		mkdir -p ${l_ldom_dir}/kernel/drv
		rsh ${l_ldom_hostname} "ifconfig -a" >  ${l_ldom_dir}/ifconfig.txt
                rsh ${l_ldom_hostname} "pkg list -v" >  ${l_ldom_dir}/pkglist.txt
                rcp ${l_ldom_hostname}:/etc/system ${l_ldom_dir}/etc
                rcp ${l_ldom_hostname}:/etc/hosts ${l_ldom_dir}/etc
                rcp ${l_ldom_hostname}:/etc/rc2.d/S99spec ${l_ldom_dir}/etc/rc2.d
                rcp ${l_ldom_hostname}:/kernel/drv/ixgbe.conf ${l_ldom_dir}/kernel/drv
                rcp ${l_ldom_hostname}:/kernel/drv/pcieb.conf ${l_ldom_dir}/kernel/drv
		rsh ${l_ldom_hostname} "dladm show-etherstub" > ${l_ldom_dir}/dladm_show-etherstub.txt
		rsh ${l_ldom_hostname} "metastat -a" > ${l_ldom_dir}/metastat.txt
		rsh ${l_ldom_hostname} "zoneadm list -v" > ${l_ldom_dir}/zoneadm_list-v.txt
		rsh ${l_ldom_hostname} "prtconf" > ${l_ldom_dir}/prtconf.txt
		rsh ${l_ldom_hostname} "cat /etc/path_to_inst" > ${l_ldom_dir}/etc/path_to_inst
		rsh ${l_ldom_hostname} "df -h" > ${l_ldom_dir}/df.txt
		rsh ${l_ldom_hostname} "hostname" > ${l_ldom_dir}/hostname.txt
		rsh ${l_ldom_hostname} "mount -v" > ${l_ldom_dir}/mount.txt
		rsh ${l_ldom_hostname} "ps -eaf" > ${l_ldom_dir}/ps-eaf.txt
		rsh ${l_ldom_hostname} "ps -eaflc" > ${l_ldom_dir}/ps-eaflc.txt
		rsh ${l_ldom_hostname} "netstat -a" > ${l_ldom_dir}/netstat.txt
		rsh ${l_ldom_hostname} "uname" > ${l_ldom_dir}/uname.txt
		rsh ${l_ldom_hostname} "uptime" > ${l_ldom_dir}/uptime.txt
		rsh ${l_ldom_hostname} "dladm show-vnic" > ${l_ldom_dir}/dladm_show-vnic.txt
		rsh ${l_ldom_hostname} "svcs" > ${l_ldom_dir}/svcs.txt
		rsh ${l_ldom_hostname} "zpool status" > ${l_ldom_dir}/zpool-status.txt
		rsh ${l_ldom_hostname} "cat /etc/release" > ${l_ldom_dir}/etc/release
		rsh ${l_ldom_hostname} "cat /etc/nsswitch.conf" > ${l_ldom_dir}/etc/nsswitch.conf
		rsh ${l_ldom_hostname} "cat /etc/inittab" > ${l_ldom_dir}/etc/inittab
		rsh ${l_ldom_hostname} "cat /etc/vfstab" > ${l_ldom_dir}/etc/vfstab
		rsh ${l_ldom_hostname} "swap -l" > ${l_ldom_dir}/swap.txt
		rsh ${l_ldom_hostname} "psrinfo -pv" > ${l_ldom_dir}/psrinfo.txt
		rsh ${l_ldom_hostname} "psrset -i" > ${l_ldom_dir}/psrset.txt
		rsh ${l_ldom_hostname} "psrset -Q 1" > ${l_ldom_dir}/psrset-Q_1.txt
		rsh ${l_ldom_hostname} "psrset -Q 2" > ${l_ldom_dir}/psrset-Q_2.txt
		if ((i==0));
		then
			rcp ${l_ldom_hostname}:/export/home/sys_control/LDOM1_MAKE_ZONE_BINDINGS_34tiles_2LDOMs  ${l_ldom_dir}
		else
			rcp ${l_ldom_hostname}:/export/home/sys_control/LDOM2_MAKE_ZONE_BINDINGS_34tiles_2LDOMs  ${l_ldom_dir}
		fi
		for vm in $(eval echo $VM_RANGE);
        	do
                	VM=$(echo $vm | tr [a-z] [A-Z])
                	for j in $(eval echo $TILE_RANGE);
                	do
				if((${TILE_TO_LDOM[$j]} == i));
				then
                       			eval cp /etc/zones/$(echo \${${VM}_HOSTNAME[$((j-1))]}).xml ${l_ldom_dir}/etc/zones
				fi
                	done
        	done
	done
	echo ""
}

function collect_comstar()
{
	if (($DEBUG_MODE == 1));
        then
                echo "collect COMSTAR config"
        fi

#return 0

	for ((i=0; i<${COMSTAR_NUM}; i++))
	do
		l_comstar_hostname=${COMSTAR_HOSTNAME[$i]}
		echo "Connecting COMSTAR$((i+1)) via ${l_comstar_hostname}"
		l_comstar_dir=${OUTPUT_DIR}/${OUTPUT_SUBDIR_L1}/${OUTPUT_SUBDIR_L2_1}/storage_server/unit$((i+1))
		mkdir -p ${l_comstar_dir}/etc
                mkdir -p ${l_comstar_dir}/kernel/drv
                rsh ${l_comstar_hostname} "ifconfig -a" >  ${l_comstar_dir}/ifconfig.txt
                rsh ${l_comstar_hostname} "pkg list -v" >  ${l_comstar_dir}/pkglist.txt
                rcp ${l_comstar_hostname}:/etc/system ${l_comstar_dir}/etc
                rcp ${l_comstar_hostname}:/etc/hosts ${l_comstar_dir}/etc
                rcp ${l_comstar_hostname}:/kernel/drv/ixgbe.conf ${l_comstar_dir}/kernel/drv
                rcp ${l_comstar_hostname}:/kernel/drv/pcieb.conf ${l_comstar_dir}/kernel/drv
                rsh ${l_comstar_hostname} "dladm show-etherstub" > ${l_comstar_dir}/dladm_show-etherstub.txt
                rsh ${l_comstar_hostname} "metastat -a" > ${l_comstar_dir}/metastat.txt
                rsh ${l_comstar_hostname} "prtconf" > ${l_comstar_dir}/prtconf.txt
                rsh ${l_comstar_hostname} "cat /etc/path_to_inst" > ${l_comstar_dir}/etc/path_to_inst
                rsh ${l_comstar_hostname} "df -h" > ${l_comstar_dir}/df.txt
                rsh ${l_comstar_hostname} "hostname" > ${l_comstar_dir}/hostname.txt
                rsh ${l_comstar_hostname} "mount -v" > ${l_comstar_dir}/mount.txt
                rsh ${l_comstar_hostname} "ps -eaf" > ${l_comstar_dir}/ps-eaf.txt
                rsh ${l_comstar_hostname} "netstat -a" > ${l_comstar_dir}/netstat.txt
                rsh ${l_comstar_hostname} "uname" > ${l_comstar_dir}/uname.txt
                rsh ${l_comstar_hostname} "uptime" > ${l_comstar_dir}/uptime.txt
                rsh ${l_comstar_hostname} "dladm show-vnic" > ${l_comstar_dir}/dladm_show-vnic.txt
                rsh ${l_comstar_hostname} "svcs" > ${l_comstar_dir}/svcs.txt
                rsh ${l_comstar_hostname} "zpool status" > ${l_comstar_dir}/zpool-status.txt
                rsh ${l_comstar_hostname} "cat /etc/release" > ${l_comstar_dir}/etc/release
                rsh ${l_comstar_hostname} "cat /etc/nsswitch.conf" > ${l_comstar_dir}/etc/nsswitch.conf
                rsh ${l_comstar_hostname} "cat /etc/inittab" > ${l_comstar_dir}/etc/inittab
                rsh ${l_comstar_hostname} "cat /etc/vfstab" > ${l_comstar_dir}/etc/vfstab
                rsh ${l_comstar_hostname} "swap -l" > ${l_comstar_dir}/swap.txt
                rsh ${l_comstar_hostname} "psrinfo -pv" > ${l_comstar_dir}/psrinfo.txt
	done
	echo ""
}

function collect_all()
{
	collect_web
	collect_infra
	collect_db
	collect_japp
	collect_mail
	collect_batch
	collect_client
	collect_sut
}

function do_work()
{
        if (($DEBUG_MODE == 1));
	then
		echo "PARAM: $PARAM"
		eval echo "Has \${#${PARAM}_VALUE[@]} value\(s\)"
		for l_param_value in $(eval echo \${${PARAM}_VALUE[@]})
		do
        		echo ${l_param_value}
        	done
		echo ""
        fi
        case $PARAM in
		web)
			collect_web
			;;
		infra)
			collect_infra
			;;
		db)	
			collect_db
			;;
		japp)
			collect_japp
			;;
		mail)
			collect_mail
			;;
		batch)
			collect_batch
			;;	
                client)
			collect_client
			;;
		sut)
			collect_sut
			;;
		ldom | LDOM)
			collect_ldom
			;;
		comstar | COMSTAR)
			collect_comstar
			;;
                all)
			collect_all
			;;
		*)
       esac
}

function param_preparing
{
	l_vm_range=""
	l_tile_range=""
	for PARAM in ${PARAMS[@]}
        do
		case $PARAM in
		web | infra | db | japp | mail | batch )
			l_vm_range="${l_vm_range} $PARAM"
			;;
		client | sut | all )
			;;
                o)
			# Take the first value as the output directory
			eval OUTPUT_DIR=${o_VALUE[0]}
			if [ ! -d "${OUTPUT_DIR}/${OUTPUT_SUBDIR_L1}/${OUTPUT_SUBDIR_L2_1}" ]; then
				mkdir -p ${OUTPUT_DIR}/${OUTPUT_SUBDIR_L1}/${OUTPUT_SUBDIR_L2_1}
			fi
			if [ ! -d "${OUTPUT_DIR}/${OUTPUT_SUBDIR_L1}/${OUTPUT_SUBDIR_L2_2}" ]; then
				mkdir -p ${OUTPUT_DIR}/${OUTPUT_SUBDIR_L1}/${OUTPUT_SUBDIR_L2_2}
			fi
			if (($DEBUG_MODE == 1));
        		then
				echo "output_dir set to $OUTPUT_DIR"
				echo ""
			fi
			;;
		tile)
			for l_tile_value in ${tile_VALUE[@]}
			do
				if [[ "${l_tile_value}" = "even" ]];
				then
					l_parity=1
				elif [[ "${l_tile_value}" = "odd" ]];
				then
					l_parity=0
				else
                			RANGE_START=`echo $l_tile_value | awk -F- '{print $1}'`
                			RANGE_END=`echo $l_tile_value | awk -F- '{print $2}'`
					if [ "${RANGE_END}" = "" ]; then
						l_tile_range="${l_tile_range} ${RANGE_START}" 
					else
						l_tile_range="${l_tile_range} {${RANGE_START}..${RANGE_END}}"
					fi
				fi
			done
			if [ "${l_parity}" != "" ];
			then
				for i in $(eval echo ${l_tile_range})
				do
					if (( $((i%2^l_parity)) == 1 )); 
					then
						p_tile_range="${p_tile_range} $i"
					fi
				done
			l_tile_range=${p_tile_range}
			fi
			;;
		LDOM | ldom )
			IS_LDOM=1
                        echo "LDOM param: LDOM_NUM = $LDOM_NUM MAX_TILE_NUM = $MAX_TILE_NUM  "
		#	for i in $(eval echo {1..$MAX_TILE_NUM..$LDOM_NUM})
		#	do
	        #			for j in $(eval echo {0..$((LDOM_NUM-1))})
	        #			do
	        #				TILE_TO_LDOM[$i]=$j
	        #			echo "TILE_TO_LDOM[$i]: ${TILE_TO_LDOM[$i]} "
	        #				((i++))
	        #			done
	        #		done
                # mappings from TILES to LDOM number
                echo "Mappings to LDOMs are defined in this script in table: tile_map"
			;;
		COMSTAR | comstar)
			;;
		h)
			usage
			exit
			;;
		*)
			echo "Unknown parameter \"$PARAM\""
                        usage
                        exit 1
                esac
	done
	if [ "${l_tile_range}" != "" ];
	then
		TILE_RANGE=${l_tile_range}
	fi
	if [ "${l_vm_range}" != "" ];
	then
		VM_RANGE=${l_vm_range}
	fi
 	if (($DEBUG_MODE == 1));
        then
		echo "tile range: $TILE_RANGE"
                echo "VM range: $VM_RANGE"
                echo ""
        fi
}
 
# Parse command line parameters
PARAM_INDEX=0
COLLECTION_SCRIPT=$0
echo "Collection script name: " ${COLLECTION_SCRIPT}
while [ "$1" != "" ]; 
do 
	if [ "${1:0:1}" = "-" ]; then
                PARAM=`echo $1 | awk -F- '{print $2}'`
                eval PARAMS[$PARAM_INDEX]=$PARAM
		#echo $PARAM
                VALUE_INDEX=0
                shift
                while [ "${1:0:1}" != "-" ] && [ "$1" != "" ]; do
                        eval ${PARAM}_VALUE[$VALUE_INDEX]=$1
                        #eval echo $(echo \$${PARAM}_VALUE[$VALUE_INDEX])
                        ((VALUE_INDEX ++))
                        shift
                done
		((PARAM_INDEX++))
	else
		echo "Unknown parameter \"$1\""
		usage
		exit 1
        fi
done

# Parameter preparing and error checking
param_preparing

# Collect config files
date > ${OUTPUT_DIR}/${OUTPUT_SUBDIR_L1}/${DATA_COLLECTION_START_FILE_NAME}
for PARAM in ${PARAMS[@]}
do
       	do_work
done
mkdir -p ${OUTPUT_DIR}/${OUTPUT_SUBDIR_L1}/${COLLECT_SCRIPT_DIR_NAME}/${OUTPUT_SUBDIR_LOGS}
cp ${COLLECTION_SCRIPT} ${OUTPUT_DIR}/${OUTPUT_SUBDIR_L1}/${COLLECT_SCRIPT_DIR_NAME}
date > ${OUTPUT_DIR}/${OUTPUT_SUBDIR_L1}/${DATA_COLLECTION_END_FILE_NAME}
