#!/bin/ksh
#starts/stops all instances of appserver or the emulator.

usage()
{ 
echo "usage:"
echo $0 start emu
echo $0 start svr domain
echo $0 stop emu run_output_dir
echo $0 stop svr domain run_output_dir 
}

#pick environment sent by master script
if [ -f /export/ecperf/.ecperfenv ]
then
  echo picking up remote env
. /export/ecperf/.ecperfenv
fi

SUDO=/export/local/bin/sudo
#APPSERVER=${APPSERVER:-wls121}
APPSERVER=${APPSERVER:-wls103}
#WL_HOME=${WL_HOME:-"$HOME/wls121/wlserver"}
WL_HOME=${WL_HOME:-"$HOME/wls103/wlserver_10.3"}
JAVA_HOME="/usr/java"
#JAVA_HOME="/export/home/VMs/jdk1.6.0_25"
JAVA_OPTIONS=${JAVA_OPTIONS:-"-server -XX:+AggressiveHeap -Xmx2400m \
 -Xms2400m -Xmn1024m -verbosegc -XX:MaxTenuringThreshold=3 -XX:SurvivorRatio=20"}
SUP_JAVA_OPTIONS=${SUP_JAVA_OPTIONS:-"-server -XX:+AggressiveHeap -Xmx1200m \
 -Xms1200m -Xmn512m -verbosegc -XX:MaxTenuringThreshold=3 -XX:SurvivorRatio=20"}
EMU_JAVA_OPTIONS=${EMULATOR_OPTS:-"-server -Xms256m -Xmx256m"}
EMU_JAVA_HOME=${EMULATOR_JVM:-"/export/VMs/jdk1.5.0_06"}
export WL_HOME JAVA_HOME JAVA_OPTIONS EMU_JAVA_OPTIONS EMU_JAVA_HOME

#WL_DIR=${WL_HOME}/../user_domains/jasdomain
WL_DIR=$HOME/user_domains/jasdomain
WL_DOMAIN=jasdomain
WL_SERVERIP=`hostname`
WL_SERVERPORT=7001
WL_PW=weblogic
WL_USER=system
export WL_DOMAIN WL_SERVERIP WL_SERVERPORT WL_PW WL_USER

echo $WL_SERVERIP

EMU_DOMAIN=emulatordomain
EMU_SERVER=emulatorserver
EMU_SERVERIP=jasemulator
EMU_SERVERPORT=7011
EMU_DIR=${HOME}/user_domains/emulatordomain
export EMU_DOMAIN EMU_SERVER EMU_SERVERIP EMU_SERVERPORT

#Most of the time, we expect these variables to be set in the
#environment
ULTRASPARC=${ULTRASPARC:-IV}
CLUSTERSIZE=${CLUSTERSIZE:-1}
CLUSTERSIZE=1
THREADPOOLSIZE=${THREADPOOLSIZE:-35}
DBPOOLSIZE=${DBPOOLSIZE:-40}
NATIVEIO=${NATIVEIO:-true}
READERS=${READERS:-33}
POSIX=${POSIX:-12}
DBTYPE=db
CACHESIZE=${CACHESIZE:-200}
DRIVERTYPE=${DRIVERTYPE:-type4}
TUNETYPE=manual
#TUNETYPE=autotune
#Have unique names for the server domains
HID=`hostname`
echo ${HID}
NUMPROCS=${NUMPROCS:-0}
export THREADPOOLSIZE DBPOOLSIZE NATIVEIO READERS POSIX CACHESIZE DBTYPE TUNETYPE HID

command=$1
target=$2
domain=$3
dir=$4

RUN_SUPDOMAIN=no

while [ $# -gt 0 ]
do
  case $1 in
    '-use_extra_supdomain')
      sup_host=`grep "yessup" /export/scripts/host_map.txt | cut -d: -f1`
      if [ `hostname` = $sup_host ]
      then
        RUN_SUPDOMAIN=yes
      fi
      shift
      ;;
    *)
      shift
      ;;
  esac
done 

case $target in

emu)
   if [ $command = "start" ]; then
     cd $EMU_DIR
     echo "starting emulator on `hostname` in `pwd`"
     ./wls_cleanup.sh
     ./startWebLogic.sh > weblogic.log 2>&1 &
     started=false
     while [ "$started" = "false" ]; do
       # give it a chance to start up
       sleep 30 
       grep -i 'Server started in RUNNING mode' weblogic.log >/dev/null 2>&1
       if [ $? = 0 ]; then
         started=true
       else 
         echo "`hostname` waiting for server emulatorserver to start"
       fi
     done
     echo "Emulator started"
     exit 0
   elif [ $command = "stop" ]; then
     cd $EMU_DIR
     echo "stopping emulator in `hostname`"
     ${JAVA_HOME}/bin/java -classpath ${WL_HOME}/server/lib/weblogic.jar \
        weblogic.Admin -url ${EMU_SERVERIP}:${EMU_SERVERPORT} \
        FORCESHUTDOWN -username ${WL_USER} -password ${WL_PW}
     #pkill java
     dir=$3
     if [ "$dir" != "" ]; then
       /bin/cp weblogic.log $dir/weblogic.emu.log
       /bin/cp config/config.xml $dir/config.emu.xml
       cd logs
       for j in *
       do
         /bin/cp $j $dir/emu_$j
       done
     fi
     exit 0
   else
     usage
     exit 1
   fi  
   ;;
svr) ;;
*)
  usage
  exit 1
  ;;
esac




############ server start/stop process ##########################
 
if [ $ULTRASPARC != "IV" ]; then
    allpsr=`/usr/sbin/psrinfo | grep -v off-line | awk '{ print $1 }'`
else
    allpsr=`/usr/sbin/psrinfo -pv | awk '{print $9}' | sed 's/(//' | sed 's/,//'`
fi

#set $allpsr
numpsr=$#
if [ $NUMPROCS -gt $numpsr ]; then
    echo "NUMPROCS is gt $numpsr."
    NUMPROCS=$numpsr
fi
curPsrSet=0
if [ $NUMPROCS != 0 ]; then
    psrPerSet=`expr $NUMPROCS / $CLUSTERSIZE`
    maxPsrSet=$CLUSTERSIZE
    while [ "`expr $psrPerSet \* $maxPsrSet`" -ge "$numpsr" ];
    do
        maxPsrSet=`expr $maxPsrSet - 1`
    done
else
    maxPsrSet=0
fi

nextPsrSet() {
    if [ $curPsrSet -lt $maxPsrSet ]; then
        tmp=$curPsrSet
        curPsrSet=`expr $curPsrSet + 1`
        $SUDO /usr/sbin/psrset -c
        set $allpsr
        numShift=`expr $psrPerSet \* $tmp`
        shift $numShift
        tmp=$psrPerSet
        while [ $tmp -gt 0 ];
        do
            core=`expr $1 + 512`
            $SUDO /usr/sbin/psrset -a $curPsrSet $1 $core
            shift
            tmp=`expr $tmp - 1`
        done
    else
        curPsrSet=0
        maxPsrSet=0
    fi
}

case $command in

start)
    /bin/rm /var/tmp/spec* >/dev/null 2>&1
    cd $WL_HOME/..
#    ${SUDO} ./../user_domains/fixdns.sh stop $RUN_SUPDOMAIN
#    ${SUDO} ./../user_domains/fixdns.sh start $RUN_SUPDOMAIN

#allow mix of drivers
LEFT=$DRIVERTYPE
DRIVER_INST[0]=nada
DRIVER_CNT=1
echo $LEFT | grep "," >/dev/null 2>&1
while [ $? = 0 ]
do
  DRIVER_INST[$DRIVER_CNT]=`echo $LEFT | cut -d, -f1`
  LEFT=`echo $LEFT | cut -d, -f2-`
  echo DRIVER_INST[$DRIVER_CNT] = ${DRIVER_INST[$DRIVER_CNT]}
  let "DRIVER_CNT = DRIVER_CNT + 1"
  echo $LEFT | grep "," >/dev/null 2>&1
done
DRIVER_INST[$DRIVER_CNT]=$LEFT
#echo DRIVER_INST[$DRIVER_CNT] = ${DRIVER_INST[$DRIVER_CNT]}

    DRIVER_LOOP=1
    i=$domain

        cd $WL_DIR-$i
        /bin/rm -rf filestore-1/* >/dev/null 2>&1
        /bin/rm -rf filestore-1/.* >/dev/null 2>&1
        /bin/rm -rf filestore/* >/dev/null 2>&1
        /bin/rm -rf /tmp/filestore >/dev/null 2>&1
	/usr/bin/mkdir -p /tmp/filestore >/dev/null 2>&1
        /bin/rm -rf servers/${HID}_jasserver-$i/* >/dev/null 2>&1
        /bin/rm -rf servers/${HID}_jasserver-$i/.* >/dev/null 2>&1
        /bin/rm -rf ${HID}_jasserver-$i >/dev/null 2>&1
        /bin/rm -rf config_next >/dev/null 2>&1
        /bin/rm -rf pending >/dev/null 2>&1
        /bin/rm -rf bin >/dev/null 2>&1
        /bin/rm  -f *.out >/dev/null 2>&1
        /bin/rm  -f *.log >/dev/null 2>&1
        /bin/rm  -f *.dump >/dev/null 2>&1
        /bin/rm  -f *.dmp >/dev/null 2>&1
        /bin/rm  -f *.mdmp >/dev/null 2>&1

#	echo "template is config.xml.${DBTYPE}${DRIVER_INST[$DRIVER_LOOP]}.${TUNETYPE}"
        # generalize templates
        SERVER_INDX=$i
        export SERVER_INDX
        sh ../sedfile2 < ../config.xml.${DBTYPE}${DRIVER_INST[$DRIVER_LOOP]}.t.${TUNETYPE} > config/config.xml
        /bin/touch config/config.xml config.lok
echo "pre-load"
        LD_PRELOAD_32=/usr/lib/libumem.so.1  ./startWebLogic.sh ${HID}_jasserver-$i > weblogic.log 2>&1 & pid=$!
#        LD_PRELOAD_32=/usr/lib/libmtmalloc.so.1  ./startWebLogic.sh ${HID}_jasserver-$i > weblogic.log 2>&1 & pid=$!

        i=$domain
        # give it a chance to start up
        while [ $i -gt 0 ];
        do
    	    sleep 30
	    grep -i 'Server started in RUNNING mode' $WL_DIR-$i/weblogic.log >/dev/null 2>&1
	    if [ $? = 0 ]; then
		i=0
                echo "`hostname`: server ${HID}_jasserver-$i already started"
	    else 
                echo "`hostname`: waiting for server ${HID}_jasserver-$i to start"
	    fi
        done

    # un-pbind JVM
    /usr/sbin/pbind -U

    ;;

stop)
    cd $WL_HOME/..
    i=$domain
    if [ $i -gt 0 ];
    then
       echo "`hostname` stopping server ${HID}_jasserver-$i"
        cd $WL_DIR-$i
	#echo "Waiting to collect MBeanStats and JDBCConnectionPool stats"
        #${JAVA_HOME}/bin/java -classpath ${WL_HOME}/server/lib/weblogic.jar \
	#    weblogic.Admin -url t3://${WL_SERVERIP}:${WL_SERVERPORT} \
	#    -username ${WL_USER} -password ${WL_PW} GET -pretty \
	#    -type EJBCacheRuntime >mbean.$i.out
        #/export/scripts/mbean.sh mbean.$i.out > mbean_sum.$i.out
	#${JAVA_HOME}/bin/java -classpath ${WL_HOME}/server/lib/weblogic.jar \
	#    weblogic.Admin -url t3://${WL_SERVERIP}-$HOST_INDX$ii:${WL_SERVERPORT} \
	#    -username ${WL_USER} -password ${WL_PW} GET -pretty \
	#    -type JDBCConnectionPoolRuntime > jdbc.$i.out
        #./wls_stats.sh > wls_stats.$i.out
	# sleep 160
        ${JAVA_HOME}/bin/java -classpath ${WL_HOME}/server/lib/weblogic.jar \
             weblogic.Admin -url ${WL_SERVERIP}:${WL_SERVERPORT} \
	     FORCESHUTDOWN -username ${WL_USER} -password ${WL_PW}
        if [ "$dir" != "" ]; then
            sleep 30
	    /bin/mv mbean* $dir
	    #/bin/mv jdbc* $dir
	    /bin/mv wls_stats*.out $dir
            cd $WL_DIR-$i
            /bin/cp weblogic.log $dir/weblogic.$i.log
            /bin/cp config/config.xml $dir/config.xml.$i
            /bin/cp config/jdbc/CP-specConnectionPool-jdbc.xml $dir
            /bin/cp config/jdbc/CP-auditConnectionPool-jdbc.xml $dir
	    /bin/cp servers/${HID}_jasserver-$i/logs/*.log $dir
            #Commenting below as errors create too many files
	    #cd logs
	    #for j in *
	    #do
	    #    /bin/cp $j $dir/$j.$i
	    #done
        fi
	#${SUDO} /usr/sbin/psrset -n $i > /dev/null 2>&1
        #${SUDO} /usr/sbin/psrset -d $i > /dev/null 2>&1
    fi
    /export/local/bin/slay java >/dev/null 2>&1
    /export/local/bin/slay -9 java >/dev/null 2>&1
    cd $WL_HOME/..
#    ${SUDO} ./../user_domains/fixdns.sh stop
    ;;

*)
    usage
    exit 1
    ;;

esac
