#!/bin/sh
# *************************************************************************
# This script is used to set up your environment for SPECjAppServer running with
# WebLogic Server. 
#
# *************************************************************************

#WL_HOME="$HOME/wls121/wlserver"
WL_HOME="$HOME/wls103/wlserver_10.3"
JAVA_HOME="/usr/java"
#JAVA_HOME="/export/home/VMs/jdk1.6.0_25"
export WL_HOME JAVA_HOME

WL_PATCHES=
export WL_PATCHES

#JDBC_CLASSPATH=/export/home/oracle/jdbc/lib/ojdbc6.jar
export JDBC_CLASSPATH

WL_DOMAIN=jasdomain-1
WL_SERVER=${HID}_jasserver-1
WL_SERVERIP=`hostname`
WL_SERVERPORT=7001
export WL_DOMAIN WL_SERVER WL_SERVERIP WL_SERVERPORT

WL_CL_ADMINIP=`hostname`
WL_CL_ADMINPORT=7001
WL_CL_MULTICAST=224.0.10.42
export WL_CL_ADMINIP WL_CL_ADMINPORT WL_CL_MULTICAST

WL_USER=system
WL_PW=weblogic
STARTMODE=true
export WL_USER WL_PW STARTMODE

JAVA_OPTIONS="-server -Xms1700m -Xmx1700m -Xmn1000m -Xss128k -XX:+AggressiveHeap -XX:+UseParallelGC -XX:ParallelGCThreads=8 -XX:PermSize=128m -XX:LargePageSizeInBytes=4m -XX:+UseParallelOldGC -verbose:gc -XX:+PrintGCDetails -XX:+PrintGCTimeStamps"

#JAVA_OPTIONS="-server -Xms3300m -Xmx3300m -Xmn1600m -Xss128k -XX:+AggressiveHeap -XX:+UseParallelGC -XX:ParallelGCThreads=32 -XX:PermSize=128m -XX:LargePageSizeInBytes=4m -XX:+UseParallelOldGC -verbose:gc -XX:+PrintGCDetails -XX:+PrintGCTimeStamps"

WL_OPTIONS="-Dweblogic.management.discover=false -Dweblogic.SocketReaders=2 -Dweblogic.StuckThreadMaxTime=900 -Dweblogic.diagnostics.debug.DebugLogger.DISABLED=true -Dweblogic.management.allowClearTextPasswords=true"
export JAVA_OPTIONS WL_OPTIONS

# Set first two positional parameters to SERVER_NAME and ADMIN_URL
if [ -n "${1}" -a "${SERVER_NAME}" = "" ]; then
  SERVER_NAME="${1}"
fi

if [ -n "${2}" -a "${ADMIN_URL}" = "" ]; then
  ADMIN_URL="${2}"
fi

# Check that the WebLogic classes are where we expect them to be
if [ ! -f "${WL_HOME}/server/lib/weblogic.jar" ]; then
  echo 
  echo "The WebLogic Server wasn't found in directory ${WL_HOME}/server."
  echo "Please edit the setEnv.sh script so that the WL_HOME"
  echo "variable points to the WebLogic installation directory."
  exit 2
fi

# Check that java is where we expect it to be
if [ ! -d "${JAVA_HOME}/bin" ]; then
  echo 
  echo "The JDK wasn't found in directory ${JAVA_HOME}."
  echo "Please edit the setEnv.sh script so that the JAVA_HOME"
  echo "variable points to the location of your JDK."
  exit 2
fi

# Try to increase file descriptors.
if [ ! -n "`uname -s |grep -i cygwin || uname -s |grep -i windows_nt || \
	    uname -s |grep -i HP-UX`" ]; then
 maxfiles=`ulimit -S -n`
 if [ "${maxfiles}" -lt 32768 ]; then
   ulimit -n 32768
 fi
 echo ulimit is `ulimit -n`
fi


# Figure out how to load java native libraries
case `uname -s` in
AIX)
  if [ -n "${LIBPATH}" ]; then
    LIBPATH=${LIBPATH}:${WL_HOME}/server/native/aix/ppc
  else
    LIBPATH=${WL_HOME}/server/native/aix/ppc
  fi
  export LIBPATH
;;
HP-UX)
  arch=`uname -m`
  if [ "${arch}" = "ia64" ]; then
    arch=IPF32
  else
    arch=PA_RISC
  fi
  if [ -n "${SHLIB_PATH}" ]; then
    SHLIB_PATH=${SHLIB_PATH}:${WL_HOME}/server/native/hpux11/${arch}:${WL_HOME}/server/native/hpux11/${arch}/oci920_8
  else
    SHLIB_PATH=${WL_HOME}/server/native/hpux11/${arch}:${WL_HOME}/server/native/hpux11/${arch}/oci920_8
  fi
  export SHLIB_PATH
;;
LINUX|Linux)
  arch=`uname -m`
# uncomment if using a 32 bit JVM on a 64-bit x86_64 OS
#  if [ "${arch}" = "x86_64" ]; then
#    arch=i686
#  fi
  if [ -n "${LD_LIBRARY_PATH}" ]; then
    LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${WL_HOME}/server/native/linux/${arch}:${WL_HOME}/server/native/linux/${arch}/oci920_8
  else
    LD_LIBRARY_PATH=${WL_HOME}/server/native/linux/${arch}:${WL_HOME}/server/native/linux/${arch}/oci920_8
  fi
  export LD_LIBRARY_PATH
;;
OSF1)
  if [ -n "${LD_LIBRARY_PATH}" ]; then
    LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${WL_HOME}/server/native/tru64unix
  else
    LD_LIBRARY_PATH=${WL_HOME}/server/native/tru64unix
  fi
  export LD_LIBRARY_PATH
;;
SunOS)
  arch=`uname -p`
  if [ "${arch}" = "i386" ]; then
    arch=x86
  fi
  if [ -n "${LD_LIBRARY_PATH}" ]; then
    LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${WL_HOME}/server/native/solaris/${arch}:${WL_HOME}/server/native/solaris/${arch}/oci920_8
  else
    LD_LIBRARY_PATH=${WL_HOME}/server/native/solaris/${arch}:${WL_HOME}/server/native/solaris/${arch}/oci920_8
  fi
  export LD_LIBRARY_PATH
;;
Windows_NT*)
  CLASSPATHSEP=\;
  PATHSEP=\;
;;
CYGWIN*)
  CLASSPATHSEP=\;
;;
*)
  echo "$0: Don't know how to set the shared library path for `uname -s`.  "
esac


if [ "${CLASSPATHSEP}" = "" ]; then
  CLASSPATHSEP=:
fi
if [ "${PATHSEP}" = "" ]; then
  PATHSEP=:
fi
export PATHSEP CLASSPATHSEP

CLASSPATH="${JAVA_HOME}/lib/tools.jar${CLASSPATHSEP}${WL_HOME}/server/lib/weblogic_sp.jar${CLASSPATHSEP}${WL_HOME}/server/lib/weblogic.jar${CLASSPATHSEP}${CLASSPATH}"
export CLASSPATH

# Set up PATH
if [ `uname -s` = "CYGWIN32/NT" ]; then
# If we are on an old version of Cygnus we need to turn <letter>:/ in the path
# to //<letter>/
  WL_HOME_CYGWIN=`echo $WL_HOME | sed 's#\([a-zA-Z]\):#//\1#g'`
  JAVA_HOME_CYGWIN=`echo $JAVA_HOME | sed 's#\([a-zA-Z]\):#//\1#g'`
  WL_USE_64BITDLL=
  if [ "${WL_USE_64BITDLL}" = "true" ]; then
    PATH="${WL_HOME_CYGWIN}/server/native/win/64${PATHSEP}${WL_HOME_CYGWIN}/server/bin${PATHSEP}${JAVA_HOME_CYGWIN}/jre/bin${PATHSEP}${JAVA_HOME_CYGWIN}/bin${PATHSEP}${PATH}${PATHSEP}${WL_HOME_CYGWIN}/server/native/win/64/oci920_8"
  else
    PATH="${WL_HOME_CYGWIN}/server/native/win/32${PATHSEP}${WL_HOME_CYGWIN}/server/bin${PATHSEP}${JAVA_HOME_CYGWIN}/jre/bin${PATHSEP}${JAVA_HOME_CYGWIN}/bin${PATHSEP}${PATH}${PATHSEP}${WL_HOME_CYGWIN}/server/native/win/32/oci920_8"
  fi
else
  if [ -n "`uname -s |grep -i cygwin_`" ]; then
  # If we are on an new version of Cygnus we need to turn <letter>:/ in
  # the path to /cygdrive/<letter>/
    CYGDRIVE=`mount -ps | tail -1 | awk '{print $1}' | sed -e 's%/$%%'`
    WL_HOME_CYGWIN=`echo $WL_HOME | sed "s#\([a-zA-Z]\):#${CYGDRIVE}/\1#g"`
    JAVA_HOME_CYGWIN=`echo $JAVA_HOME | sed "s#\([a-zA-Z]\):#${CYGDRIVE}/\1#g"`
    WL_USE_64BITDLL=
    if [ "${WL_USE_64BITDLL}" = "true" ]; then
      PATH="${WL_HOME_CYGWIN}/server/native/win/64${PATHSEP}${WL_HOME_CYGWIN}/server/bin${PATHSEP}${JAVA_HOME_CYGWIN}/jre/bin${PATHSEP}${JAVA_HOME_CYGWIN}/bin${PATHSEP}${PATH}${PATHSEP}${WL_HOME_CYGWIN}/server/native/win/64/oci920_8"
    else
      PATH="${WL_HOME_CYGWIN}/server/native/win/32${PATHSEP}${WL_HOME_CYGWIN}/server/bin${PATHSEP}${JAVA_HOME_CYGWIN}/jre/bin${PATHSEP}${JAVA_HOME_CYGWIN}/bin${PATHSEP}${PATH}${PATHSEP}${WL_HOME_CYGWIN}/server/native/win/32/oci920_8"
    fi
  else
  # set PATH for other shell environments
    PATH="${WL_HOME}/server/bin${PATHSEP}${JAVA_HOME}/jre/bin${PATHSEP}${JAVA_HOME}/bin${PATHSEP}${PATH}"
    # On Windows, include WebLogic jDriver in PATH
    if [ -n "`uname -s |grep -i windows_nt`" ]; then
      WL_USE_64BITDLL=
      if [ "${WL_USE_64BITDLL}" = "true" ]; then
        PATH="${WL_HOME}/server/native/win/64${PATHSEP}${PATH}${PATHSEP}${WL_HOME}/server/native/win/64/oci920_8"
      else
        PATH="${WL_HOME}/server/native/win/32${PATHSEP}${PATH}${PATHSEP}${WL_HOME}/server/native/win/32/oci920_8"
      fi
    fi
  fi
fi
export PATH

if [ -n "${JDBC_CLASSPATH}" ]
then
	CLASSPATH="${JDBC_CLASSPATH}${CLASSPATHSEP}${CLASSPATH}"
fi

if [ -n "${WL_PATCHES}" ]
then
	for i in $WL_PATCHES
	do
		if [ ! -f $i ]
		then
			echo ERROR: PATCH $i does not exist
		fi
		if [ -n "$PATCHES" ]
		then
			PATCHES="${PATCHES}${CLASSPATHSEP}${i}"
		else
			PATCHES=$i
		fi
	done
	CLASSPATH="${PATCHES}${CLASSPATHSEP}${CLASSPATH}"
fi

